@@ -2,7 +2,7 @@
    GNU Mailutils nntp functions.  This application interactively allows users
    to contact a nntp server.
 
-   Copyright (C) 2003, 2004 Free Software Foundation
+   Copyright (C) 2003, 2004, 2005 Free Software Foundation
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -20,9 +20,8 @@
    MA 02110-1301 USA */
 
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
-#endif
-
+# include <config.h>  /* For ARG_UNUSED only */
+#endif 
 #include <sys/types.h>
 #include <unistd.h>
 #include <stdio.h>
@@ -73,9 +72,9 @@ int com_list (char *);
 int com_list_active (char *);
 int com_list_active_times (char *);
 int com_list_distributions (char *);
-int com_list_distribpats (char *);
+int com_list_distrib_pats (char *);
 int com_list_extensions (char *);
-int com_list_newsgoups (char *);
+int com_list_newsgroups (char *);
 int com_mode (char *);
 int com_mode_reader (char *);
 int com_newgroups (char *);
@@ -407,7 +406,7 @@ com_mode_reader (char *arg ARG_UNUSED)
 int
 com_head (char *arg)
 {
-  stream_t stream = NULL;
+  mu_stream_t stream = NULL;
   int status;
 
   /* No space allowed. */
@@ -426,9 +425,9 @@ com_head (char *arg)
     {
       size_t n = 0;
       char buf[128];
-      while ((stream_readline (stream, buf, sizeof buf, 0, &n) == 0) && n)
+      while ((mu_stream_readline (stream, buf, sizeof buf, 0, &n) == 0) && n)
         printf ("%s", buf);
-      stream_destroy (&stream, NULL);
+      mu_stream_destroy (&stream, NULL);
     }
    return status;
 }
@@ -436,7 +435,7 @@ com_head (char *arg)
 int
 com_body (char *arg)
 {
-  stream_t stream = NULL;
+  mu_stream_t stream = NULL;
   int status;
 
   /* No space allowed. */
@@ -455,9 +454,9 @@ com_body (char *arg)
     {
       size_t n = 0;
       char buf[128];
-      while ((stream_readline (stream, buf, sizeof buf, 0, &n) == 0) && n)
+      while ((mu_stream_readline (stream, buf, sizeof buf, 0, &n) == 0) && n)
         printf ("%s", buf);
-      stream_destroy (&stream, NULL);
+      mu_stream_destroy (&stream, NULL);
     }
    return status;
 }
@@ -465,7 +464,7 @@ com_body (char *arg)
 int
 com_article (char *arg)
 {
-  stream_t stream = NULL;
+  mu_stream_t stream = NULL;
   int status;
 
   /* No space allowed. */
@@ -484,9 +483,9 @@ com_article (char *arg)
     {
       size_t n = 0;
       char buf[128];
-      while ((stream_readline (stream, buf, sizeof buf, 0, &n) == 0) && n)
+      while ((mu_stream_readline (stream, buf, sizeof buf, 0, &n) == 0) && n)
         printf ("%s", buf);
-      stream_destroy (&stream, NULL);
+      mu_stream_destroy (&stream, NULL);
     }
    return status;
 }
@@ -564,20 +563,20 @@ int com_list (char *arg)
 int
 com_list_extensions (char *arg ARG_UNUSED)
 {
-  iterator_t iterator = NULL;
+  mu_iterator_t iterator = NULL;
   int status = mu_nntp_list_extensions (nntp, &iterator);
 
   if (status == 0)
     {
       printf ("List Extension:\n");
-      for (iterator_first (iterator);
-	   !iterator_is_done (iterator); iterator_next (iterator))
+      for (mu_iterator_first (iterator);
+	   !mu_iterator_is_done (iterator); mu_iterator_next (iterator))
 	{
 	  char *extension = NULL;
-	  iterator_current (iterator, (void **) &extension);
+	  mu_iterator_current (iterator, (void **) &extension);
 	  printf (" %s\n", extension);
 	}
-      iterator_destroy (&iterator);
+      mu_iterator_destroy (&iterator);
     }
   return status;
 }
@@ -585,21 +584,21 @@ com_list_extensions (char *arg ARG_UNUSED)
 int
 com_list_active (char *arg)
 {
-  iterator_t iterator = NULL;
+  mu_iterator_t iterator = NULL;
   int status = mu_nntp_list_active (nntp, arg, &iterator);
 
   if (status == 0)
     {
       printf ("List Active:\n");
-      for (iterator_first (iterator);
-	   !iterator_is_done (iterator); iterator_next (iterator))
+      for (mu_iterator_first (iterator);
+	   !mu_iterator_is_done (iterator); mu_iterator_next (iterator))
 	{
 	  char *buffer = NULL;
 	  char *group = NULL;
 	  unsigned long high;
 	  unsigned long low;
 	  char stat;
-	  iterator_current (iterator, (void **) &buffer);
+	  mu_iterator_current (iterator, (void **) &buffer);
 	  mu_nntp_parse_list_active (buffer, &group, &high, &low, &stat);
 	  if (group)
 	    {
@@ -608,7 +607,7 @@ com_list_active (char *arg)
 	    }
 	  printf (" high(%ld) low(%ld) status(%c)\n", high, low, stat);
 	}
-      iterator_destroy (&iterator);
+      mu_iterator_destroy (&iterator);
     }
   return status;
 }
@@ -616,20 +615,20 @@ com_list_active (char *arg)
 int
 com_list_active_times (char *arg)
 {
-  iterator_t iterator = NULL;
+  mu_iterator_t iterator = NULL;
   int status = mu_nntp_list_active_times (nntp, arg, &iterator);
 
   if (status == 0)
     {
       printf ("List Active.Times:\n");
-      for (iterator_first (iterator);
-	   !iterator_is_done (iterator); iterator_next (iterator))
+      for (mu_iterator_first (iterator);
+	   !mu_iterator_is_done (iterator); mu_iterator_next (iterator))
 	{
 	  char *buffer = NULL;
 	  char *group = NULL;
 	  char *creator = NULL;
 	  unsigned long time = 0;
-	  iterator_current (iterator, (void **) &buffer);
+	  mu_iterator_current (iterator, (void **) &buffer);
 	  mu_nntp_parse_list_active_times (buffer, &group, &time, &creator);
 	  if (group)
 	    {
@@ -655,7 +654,7 @@ com_list_active_times (char *arg)
 	    }
 	  printf ("\n");
 	}
-      iterator_destroy (&iterator);
+      mu_iterator_destroy (&iterator);
     }
   return status;
 }
@@ -663,19 +662,19 @@ com_list_active_times (char *arg)
 int
 com_list_distributions (char *arg ARG_UNUSED)
 {
-  iterator_t iterator = NULL;
+  mu_iterator_t iterator = NULL;
   int status = mu_nntp_list_distributions (nntp, arg, &iterator);
 
   if (status == 0)
     {
       printf ("List Distributions:\n");
-      for (iterator_first (iterator);
-	   !iterator_is_done (iterator); iterator_next (iterator))
+      for (mu_iterator_first (iterator);
+	   !mu_iterator_is_done (iterator); mu_iterator_next (iterator))
 	{
 	  char *buffer = NULL;
 	  char *key = NULL;
 	  char *value = NULL;
-	  iterator_current (iterator, (void **) &buffer);
+	  mu_iterator_current (iterator, (void **) &buffer);
 	  mu_nntp_parse_list_distributions (buffer, &key, &value);
 	  if (key)
 	    {
@@ -689,7 +688,7 @@ com_list_distributions (char *arg ARG_UNUSED)
 	    }
 	  printf ("\n");
 	}
-      iterator_destroy (&iterator);
+      mu_iterator_destroy (&iterator);
     }
   return status;
 }
@@ -697,20 +696,20 @@ com_list_distributions (char *arg ARG_UNUSED)
 int
 com_list_distrib_pats (char *arg ARG_UNUSED)
 {
-  iterator_t iterator = NULL;
+  mu_iterator_t iterator = NULL;
   int status = mu_nntp_list_distrib_pats (nntp, &iterator);
 
   if (status == 0)
     {
       printf ("List Distrib Pats:\n");
-      for (iterator_first (iterator);
-	   !iterator_is_done (iterator); iterator_next (iterator))
+      for (mu_iterator_first (iterator);
+	   !mu_iterator_is_done (iterator); mu_iterator_next (iterator))
 	{
 	  char *buffer = NULL;
 	  unsigned long weight = 0;
 	  char *wildmat = NULL;
 	  char *distrib = NULL;
-	  iterator_current (iterator, (void **) &buffer);
+	  mu_iterator_current (iterator, (void **) &buffer);
 	  mu_nntp_parse_list_distrib_pats (buffer, &weight, &wildmat, &distrib);
 	  printf (" weight(%ld)", weight);
 	  if (wildmat)
@@ -725,7 +724,7 @@ com_list_distrib_pats (char *arg ARG_UNUSED)
 	    }
 	  printf ("\n");
 	}
-      iterator_destroy (&iterator);
+      mu_iterator_destroy (&iterator);
     }
   return status;
 }
@@ -733,19 +732,19 @@ com_list_distrib_pats (char *arg ARG_UNUSED)
 int
 com_list_newsgroups (char *arg)
 {
-  iterator_t iterator = NULL;
+  mu_iterator_t iterator = NULL;
   int status = mu_nntp_list_newsgroups (nntp, arg, &iterator);
 
   if (status == 0)
     {
       printf ("Newsgroups:\n");
-      for (iterator_first (iterator);
-	   !iterator_is_done (iterator); iterator_next (iterator))
+      for (mu_iterator_first (iterator);
+	   !mu_iterator_is_done (iterator); mu_iterator_next (iterator))
 	{
 	  char *buffer = NULL;
 	  char *group = NULL;
 	  char *desc = NULL;
-	  iterator_current (iterator, (void **) &buffer);
+	  mu_iterator_current (iterator, (void **) &buffer);
 	  mu_nntp_parse_list_newsgroups (buffer, &group, &desc);
 	  if (group)
 	    {
@@ -759,7 +758,7 @@ com_list_newsgroups (char *arg)
 	    }
 	  printf ("\n");
 	}
-      iterator_destroy (&iterator);
+      mu_iterator_destroy (&iterator);
     }
   return status;
 }
@@ -797,7 +796,7 @@ com_next (char *arg ARG_UNUSED)
 int
 com_newgroups (char *arg)
 {
-  iterator_t iterator = NULL;
+  mu_iterator_t iterator = NULL;
   int status;
   int year, month, day, hour, min, sec, is_gmt;
   year = month = day = hour = min = sec = is_gmt = 0;
@@ -827,15 +826,15 @@ com_newgroups (char *arg)
   if (status == 0)
     {
       printf ("New Groups:\n");
-      for (iterator_first (iterator);
-	   !iterator_is_done (iterator); iterator_next (iterator))
+      for (mu_iterator_first (iterator);
+	   !mu_iterator_is_done (iterator); mu_iterator_next (iterator))
 	{
 	  char *buffer = NULL;
 	  char *group = NULL;
 	  unsigned long high = 0;
 	  unsigned long low = 0;
 	  char stat = 0;
-	  iterator_current (iterator, (void **) &buffer);
+	  mu_iterator_current (iterator, (void **) &buffer);
 	  mu_nntp_parse_newgroups (buffer, &group, &high, &low, &stat);
 	  if (group)
 	    {
@@ -844,7 +843,7 @@ com_newgroups (char *arg)
 	    }
 	  printf (" hig(%lu) low(%lu) status(%c)\n", high, low, stat);
 	}
-      iterator_destroy (&iterator);
+      mu_iterator_destroy (&iterator);
     }
   return status;
 }
@@ -852,7 +851,7 @@ com_newgroups (char *arg)
 int
 com_newnews (char *arg)
 {
-  iterator_t iterator = NULL;
+  mu_iterator_t iterator = NULL;
   char *wildmat;
   char gmt[4];
   int year, month, day, hour, min, sec, is_gmt;
@@ -884,14 +883,14 @@ com_newnews (char *arg)
   if (status == 0)
     {
       printf ("New News:\n");
-      for (iterator_first (iterator);
-	   !iterator_is_done (iterator); iterator_next (iterator))
+      for (mu_iterator_first (iterator);
+	   !mu_iterator_is_done (iterator); mu_iterator_next (iterator))
 	{
 	  char *mid = NULL;
-	  iterator_current (iterator, (void **) &mid);
+	  mu_iterator_current (iterator, (void **) &mid);
 	  printf (" %s\n", mid);
 	}
-      iterator_destroy (&iterator);
+      mu_iterator_destroy (&iterator);
     }
   return status;
 }
@@ -953,7 +952,7 @@ com_ihave (char *arg)
 int
 com_help (char *arg ARG_UNUSED)
 {
-  stream_t stream = NULL;
+  mu_stream_t stream = NULL;
   int status;
 
   status = mu_nntp_help (nntp, &stream);
@@ -961,9 +960,9 @@ com_help (char *arg ARG_UNUSED)
     {
       size_t n = 0;
       char buf[128];
-      while ((stream_readline (stream, buf, sizeof buf, 0, &n) == 0) && n)
+      while ((mu_stream_readline (stream, buf, sizeof buf, 0, &n) == 0) && n)
         printf ("%s", buf);
-      stream_destroy (&stream, NULL);
+      mu_stream_destroy (&stream, NULL);
     }
   return status;
 }
@@ -1030,12 +1029,12 @@ com_connect (char *arg)
   status = mu_nntp_create (&nntp);
   if (status == 0)
     {
-      stream_t tcp;
+      mu_stream_t tcp;
 
       if (verbose)
 	com_verbose ("on");
       status =
-	tcp_stream_create (&tcp, host, port,
+	mu_tcp_stream_create (&tcp, host, port,
 			   MU_STREAM_READ | MU_STREAM_NO_CHECK);
       if (status == 0)
 	{
