@@ -1,6 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
    Copyright (C) 1999, 2000, 2001, 2002, 2003,
-   2004 Free Software Foundation, Inc.
+   2004, 2005 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -14,7 +14,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #include "guimb.h"
 
@@ -146,7 +147,8 @@ int
 main (int argc, char *argv[])
 {
   int c = argc;
-  guimb_param_t param;
+  int index;
+  mu_guimb_param_t param;
   struct guimb_data gd;
 
   /* Native Language Support */
@@ -154,10 +156,10 @@ main (int argc, char *argv[])
 
   append_arg ("");
   mu_argp_init (program_version, NULL);
-  mu_argp_parse (&argp, &argc, &argv, 0, guimb_argp_capa, NULL, &c);
-  
+  mu_argp_parse (&argp, &argc, &argv, 0, guimb_argp_capa, &index, &c);
+
   for (; c < argc; c++)
-      append_arg (argv[c]);
+    append_arg (argv[c]);
 
   if (!user_name)
     user_name = who_am_i ();
@@ -173,7 +175,7 @@ main (int argc, char *argv[])
   /* Register the desired formats. */
   mu_register_all_formats ();
 
-  if (!argv[optind])
+  if (!argv[index])
     {
       if (default_mailbox)
 	append_arg (default_mailbox);
@@ -183,12 +185,12 @@ main (int argc, char *argv[])
     {
       collect_open_mailbox_file ();
 
-      if (argv[optind])
+      if (argv[index])
 	{
-	  for (; argv[optind]; optind++)
+	  for (; argv[index]; index++)
 	    {
-	      append_arg (argv[optind]);
-	      collect_append_file (argv[optind]);
+	      append_arg (argv[index]);
+	      collect_append_file (argv[index]);
 	    }
 	}
       else 
