@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2002, 2005 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,7 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #include "guimb.h"
 
@@ -32,34 +33,34 @@ util_error (char *fmt, ...)
 char *
 util_get_sender (int msgno)
 {
-  header_t header = NULL;
-  address_t addr = NULL;
-  message_t msg = NULL;
+  mu_header_t header = NULL;
+  mu_address_t addr = NULL;
+  mu_message_t msg = NULL;
   char buffer[512];
 
-  mailbox_get_message (mbox, msgno, &msg);
-  message_get_header (msg, &header);
-  if (header_get_value (header, MU_HEADER_FROM, buffer, sizeof (buffer), NULL)
-      || address_create (&addr, buffer))
+  mu_mailbox_get_message (mbox, msgno, &msg);
+  mu_message_get_header (msg, &header);
+  if (mu_header_get_value (header, MU_HEADER_FROM, buffer, sizeof (buffer), NULL)
+      || mu_address_create (&addr, buffer))
     {
-      envelope_t env = NULL;
-      message_get_envelope (msg, &env);
-      if (envelope_sender (env, buffer, sizeof (buffer), NULL)
-	  || address_create (&addr, buffer))
+      mu_envelope_t env = NULL;
+      mu_message_get_envelope (msg, &env);
+      if (mu_envelope_sender (env, buffer, sizeof (buffer), NULL)
+	  || mu_address_create (&addr, buffer))
 	{
 	  util_error (_("Cannot determine sender name (msg %d)"), msgno);
 	  return NULL;
 	}
     }
 
-  if (address_get_email (addr, 1, buffer, sizeof (buffer), NULL))
+  if (mu_address_get_email (addr, 1, buffer, sizeof (buffer), NULL))
     {
       util_error (_("Cannot determine sender name (msg %d)"), msgno);
-      address_destroy (&addr);
+      mu_address_destroy (&addr);
       return NULL;
     }
 
-  address_destroy (&addr);
+  mu_address_destroy (&addr);
   return strdup (buffer);
 }
 
