@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2001, 2005, 2006 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@ struct imap_auth {
   imap4d_auth_handler_fp handler;
 };
 
-static list_t imap_auth_list;
+static mu_list_t imap_auth_list;
 
 static int
 comp (const void *item, const void *data)
@@ -44,16 +44,16 @@ auth_add (char *name, imap4d_auth_handler_fp handler)
   p->handler = handler;
   if (!imap_auth_list)
     {
-      list_create (&imap_auth_list);
-      list_set_comparator (imap_auth_list, comp);
+      mu_list_create (&imap_auth_list);
+      mu_list_set_comparator (imap_auth_list, comp);
     }
-  list_append (imap_auth_list, (void*)p);
+  mu_list_append (imap_auth_list, (void*)p);
 }
 
 void
 auth_remove (char *name)
 {
-  list_remove (imap_auth_list, (void*) name);
+  mu_list_remove (imap_auth_list, (void*) name);
 }
 
 static int
@@ -90,7 +90,7 @@ _auth_try (void *item, void *data)
 void
 imap4d_auth_capability ()
 {
-  list_do (imap_auth_list, _auth_capa, NULL);
+  mu_list_do (imap_auth_list, _auth_capa, NULL);
 }
 
 int
@@ -113,7 +113,7 @@ imap4d_authenticate (struct imap4d_command *command, char *arg)
   adata.arg = sp;
   adata.username = NULL;
 
-  if (list_do (imap_auth_list, _auth_try, &adata) == 0)
+  if (mu_list_do (imap_auth_list, _auth_try, &adata) == 0)
     return util_finish (command, RESP_NO,
 			"Authentication mechanism not supported");
   
@@ -124,12 +124,15 @@ imap4d_authenticate (struct imap4d_command *command, char *arg)
 	return util_finish (command, RESP_NO,
 			    "User name or passwd rejected");
 
+      homedir = mu_normalize_path (strdup (auth_data->dir), "/");
+      if (imap4d_check_home_dir (homedir, auth_data->uid, auth_data->gid))
+	return util_finish (command, RESP_NO,
+			    "User name or passwd rejected");
+      
       if (auth_data->change_uid)
 	setuid (auth_data->uid);
 
-      homedir = mu_normalize_path (strdup (auth_data->dir), "/");
-      /* FIXME: Check for errors.  */
-      chdir (homedir);
+      util_chdir (homedir);
       namespace_init (homedir);
       syslog (LOG_INFO, _("User `%s' logged in"), adata.username);
       
