@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001, 2002 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2001, 2002, 2005  Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -13,7 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #include "imap4d.h"
 
@@ -37,32 +38,32 @@
    search queries. */
 
 struct parsebuf;
-typedef void (*inst_t) __P((struct parsebuf *pb));
+typedef void (*inst_t) (struct parsebuf *pb);
 
-static void cond_and __P((struct parsebuf *pb));
-static void cond_or __P((struct parsebuf *pb));
-static void cond_not __P((struct parsebuf *pb));
+static void cond_and (struct parsebuf *pb);
+static void cond_or (struct parsebuf *pb);
+static void cond_not (struct parsebuf *pb);
 
-static void cond_all __P((struct parsebuf *pb));                      
-static void cond_msgset __P((struct parsebuf *pb));                      
-static void cond_bcc __P((struct parsebuf *pb));                      
-static void cond_before __P((struct parsebuf *pb));                   
-static void cond_body __P((struct parsebuf *pb));                     
-static void cond_cc __P((struct parsebuf *pb));                       
-static void cond_from __P((struct parsebuf *pb));                     
-static void cond_header __P((struct parsebuf *pb));                   
-static void cond_keyword __P((struct parsebuf *pb));                  
-static void cond_larger __P((struct parsebuf *pb));                   
-static void cond_on __P((struct parsebuf *pb));                       
-static void cond_sentbefore __P((struct parsebuf *pb));               
-static void cond_senton __P((struct parsebuf *pb));                   
-static void cond_sentsince __P((struct parsebuf *pb));                
-static void cond_since __P((struct parsebuf *pb));                    
-static void cond_smaller __P((struct parsebuf *pb));                  
-static void cond_subject __P((struct parsebuf *pb));                  
-static void cond_text __P((struct parsebuf *pb));                     
-static void cond_to __P((struct parsebuf *pb));                       
-static void cond_uid __P((struct parsebuf *pb));                      
+static void cond_all (struct parsebuf *pb);                      
+static void cond_msgset (struct parsebuf *pb);                      
+static void cond_bcc (struct parsebuf *pb);                      
+static void cond_before (struct parsebuf *pb);                   
+static void cond_body (struct parsebuf *pb);                     
+static void cond_cc (struct parsebuf *pb);                       
+static void cond_from (struct parsebuf *pb);                     
+static void cond_header (struct parsebuf *pb);                   
+static void cond_keyword (struct parsebuf *pb);                  
+static void cond_larger (struct parsebuf *pb);                   
+static void cond_on (struct parsebuf *pb);                       
+static void cond_sentbefore (struct parsebuf *pb);               
+static void cond_senton (struct parsebuf *pb);                   
+static void cond_sentsince (struct parsebuf *pb);                
+static void cond_since (struct parsebuf *pb);                    
+static void cond_smaller (struct parsebuf *pb);                  
+static void cond_subject (struct parsebuf *pb);                  
+static void cond_text (struct parsebuf *pb);                     
+static void cond_to (struct parsebuf *pb);                       
+static void cond_uid (struct parsebuf *pb);                      
 
 /* A basic condition structure */
 struct cond
@@ -174,19 +175,19 @@ struct parsebuf
 
                                 /* Execution time only: */
   size_t msgno;                 /* Number of current message */
-  message_t msg;                /* Current message */ 
+  mu_message_t msg;                /* Current message */ 
 };
 
-static void put_code __P((struct parsebuf *pb, inst_t inst));
-static void parse_free_mem __P((struct parsebuf *pb));
-static void *parse_regmem __P((struct parsebuf *pb, void *mem));
-static char *parse_strdup __P((struct parsebuf *pb, char *s));
-static void *parse_alloc __P((struct parsebuf *pb, size_t size));
-static int parse_search_key_list __P((struct parsebuf *pb));
-static int parse_search_key __P((struct parsebuf *pb));
-static int parse_gettoken __P((struct parsebuf *pb, int req));
-static int search_run __P((struct parsebuf *pb));
-static void do_search __P((struct parsebuf *pb));
+static void put_code (struct parsebuf *pb, inst_t inst);
+static void parse_free_mem (struct parsebuf *pb);
+static void *parse_regmem (struct parsebuf *pb, void *mem);
+static char *parse_strdup (struct parsebuf *pb, char *s);
+static void *parse_alloc (struct parsebuf *pb, size_t size);
+static int parse_search_key_list (struct parsebuf *pb);
+static int parse_search_key (struct parsebuf *pb);
+static int parse_gettoken (struct parsebuf *pb, int req);
+static int search_run (struct parsebuf *pb);
+static void do_search (struct parsebuf *pb);
 
 int
 imap4d_search (struct imap4d_command *command, char *arg)
@@ -195,7 +196,7 @@ imap4d_search (struct imap4d_command *command, char *arg)
   char buffer[64];
   
   rc = imap4d_search0 (arg, 0, buffer, sizeof buffer);
-  return util_finish (command, rc, buffer);
+  return util_finish (command, rc, "%s", buffer);
 }
   
 int
@@ -273,22 +274,22 @@ do_search (struct parsebuf *pb)
 {
   size_t count = 0;
   
-  mailbox_messages_count (mbox, &count);
+  mu_mailbox_messages_count (mbox, &count);
 
   util_send ("* SEARCH");
   for (pb->msgno = 1; pb->msgno <= count; pb->msgno++)
     {
-      if (mailbox_get_message (mbox, pb->msgno, &pb->msg) == 0
+      if (mu_mailbox_get_message (mbox, pb->msgno, &pb->msg) == 0
 	  && search_run (pb))
 	{
 	  if (pb->isuid)
 	    {
 	      size_t uid;
-	      message_get_uid (pb->msg, &uid);
-	      util_send (" %d", uid);
+	      mu_message_get_uid (pb->msg, &uid);
+	      util_send (" %s", mu_umaxtostr (0, uid));
 	    }
 	  else
-	    util_send (" %d", pb->msgno);
+	    util_send (" %s", mu_umaxtostr (0, pb->msgno));
 	}
     }
   util_send ("\r\n");
@@ -661,10 +662,10 @@ static int
 _scan_header (struct parsebuf *pb, char *name, char *value)
 {
   char buffer[512];
-  header_t header = NULL;
+  mu_header_t header = NULL;
   
-  message_get_header (pb->msg, &header);
-  if (!header_get_value (header, name, buffer, sizeof(buffer), NULL))
+  mu_message_get_header (pb->msg, &header);
+  if (!mu_header_get_value (header, name, buffer, sizeof(buffer), NULL))
     {
       return util_strcasestr (buffer, value) != NULL;
     }
@@ -676,10 +677,10 @@ static int
 _header_date (struct parsebuf *pb, time_t *timep)
 {
   char buffer[512];
-  header_t header = NULL;
+  mu_header_t header = NULL;
   
-  message_get_header (pb->msg, &header);
-  if (!header_get_value (header, "Date", buffer, sizeof(buffer), NULL)
+  mu_message_get_header (pb->msg, &header);
+  if (!mu_header_get_value (header, "Date", buffer, sizeof(buffer), NULL)
       && util_parse_822_date (buffer, timep))
     return 0;
   return 1;
@@ -690,15 +691,15 @@ static int
 _scan_header_all (struct parsebuf *pb, char *text)
 {
   char buffer[512];
-  header_t header = NULL;
+  mu_header_t header = NULL;
   size_t fcount = 0;
   int i, rc;
 
-  message_get_header (pb->msg, &header);
-  header_get_field_count (header, &fcount);
+  mu_message_get_header (pb->msg, &header);
+  mu_header_get_field_count (header, &fcount);
   for (i = rc = 0; i < fcount; i++)
     {
-      if (header_get_field_value (header, i, buffer, sizeof(buffer), NULL))
+      if (mu_header_get_field_value (header, i, buffer, sizeof(buffer), NULL))
 	rc = util_strcasestr (buffer, text) != NULL;
     }
   return rc;
@@ -708,21 +709,21 @@ _scan_header_all (struct parsebuf *pb, char *text)
 static int
 _scan_body (struct parsebuf *pb, char *text)
 {
-  body_t body = NULL;
-  stream_t stream = NULL;
+  mu_body_t body = NULL;
+  mu_stream_t stream = NULL;
   size_t size = 0, lines = 0;
   char buffer[128];
   size_t n = 0;
   off_t offset = 0;
   int rc;
   
-  message_get_body (pb->msg, &body);
-  body_size (body, &size);
-  body_lines (body, &lines);
-  body_get_stream (body, &stream);
+  mu_message_get_body (pb->msg, &body);
+  mu_body_size (body, &size);
+  mu_body_lines (body, &lines);
+  mu_body_get_stream (body, &stream);
   rc = 0;
   while (rc == 0
-	 && stream_read (stream, buffer, sizeof(buffer)-1, offset, &n) == 0
+	 && mu_stream_read (stream, buffer, sizeof(buffer)-1, offset, &n) == 0
 	 && n > 0)
     {
       buffer[n] = 0;
@@ -790,10 +791,10 @@ cond_before (struct parsebuf *pb)
   time_t t = (time_t)_search_arg (pb);
   time_t mesg_time;
   char buffer[512];
-  envelope_t env;
+  mu_envelope_t env;
   
-  message_get_envelope (pb->msg, &env);
-  envelope_date (env, buffer, sizeof (buffer), NULL);
+  mu_message_get_envelope (pb->msg, &env);
+  mu_envelope_date (env, buffer, sizeof (buffer), NULL);
   util_parse_ctime_date (buffer, &mesg_time);
   _search_push (pb, mesg_time < t);
 }                   
@@ -814,12 +815,12 @@ void
 cond_from (struct parsebuf *pb)
 {
   char *s = _search_arg (pb);
-  envelope_t env;
+  mu_envelope_t env;
   char buffer[512];
   int rc = 0;
   
-  message_get_envelope (pb->msg, &env);
-  if (envelope_sender (env, buffer, sizeof (buffer), NULL) == 0)
+  mu_message_get_envelope (pb->msg, &env);
+  if (mu_envelope_sender (env, buffer, sizeof (buffer), NULL) == 0)
     rc = util_strcasestr (buffer, s) != NULL;
   _search_push (pb, _scan_header (pb, "from", s));
 }                     
@@ -837,9 +838,9 @@ void
 cond_keyword (struct parsebuf *pb)
 {
   char *s = _search_arg (pb);
-  attribute_t attr = NULL;
+  mu_attribute_t attr = NULL;
   
-  message_get_attribute (pb->msg, &attr);
+  mu_message_get_attribute (pb->msg, &attr);
   _search_push (pb, util_attribute_matches_flag (attr, s));
 }                  
 
@@ -849,7 +850,7 @@ cond_larger (struct parsebuf *pb)
   int n = (int) _search_arg (pb);
   size_t size = 0;
   
-  message_size (pb->msg, &size);
+  mu_message_size (pb->msg, &size);
   _search_push (pb, size > n);
 }                   
 
@@ -859,10 +860,10 @@ cond_on (struct parsebuf *pb)
   time_t t = (time_t)_search_arg (pb);
   time_t mesg_time;
   char buffer[512];
-  envelope_t env;
+  mu_envelope_t env;
   
-  message_get_envelope (pb->msg, &env);
-  envelope_date (env, buffer, sizeof (buffer), NULL);
+  mu_message_get_envelope (pb->msg, &env);
+  mu_envelope_date (env, buffer, sizeof (buffer), NULL);
   util_parse_ctime_date (buffer, &mesg_time);
   _search_push (pb, t <= mesg_time && mesg_time <= t + 86400);
 }                       
@@ -903,10 +904,10 @@ cond_since (struct parsebuf *pb)
   time_t t = (time_t)_search_arg (pb);
   time_t mesg_time;
   char buffer[512];
-  envelope_t env;
+  mu_envelope_t env;
   
-  message_get_envelope (pb->msg, &env);
-  envelope_date (env, buffer, sizeof (buffer), NULL);
+  mu_message_get_envelope (pb->msg, &env);
+  mu_envelope_date (env, buffer, sizeof (buffer), NULL);
   util_parse_ctime_date (buffer, &mesg_time);
   _search_push (pb, mesg_time >= t);
 }                    
@@ -917,7 +918,7 @@ cond_smaller (struct parsebuf *pb)
   int n = (int) _search_arg (pb);
   size_t size = 0;
   
-  message_size (pb->msg, &size);
+  mu_message_size (pb->msg, &size);
   _search_push (pb, size < n);
 }                  
 
@@ -948,7 +949,7 @@ cond_uid (struct parsebuf *pb)
   size_t uid = 0;
   int i, rc;
   
-  message_get_uid (pb->msg, &uid);
+  mu_message_get_uid (pb->msg, &uid);
   for (i = rc = 0; rc == 0 && i < n; i++)
     rc = set[i] == uid;
       
