@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2005 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -25,23 +25,23 @@
 extern "C" {
 #endif
 
-extern int body_create         __P ((body_t *, void *owner));
-extern void body_destroy       __P ((body_t *, void *owner));
-extern void * body_get_owner   __P ((body_t));
-extern int body_is_modified    __P ((body_t));
-extern int body_clear_modified __P ((body_t));
+extern int mu_body_create         (mu_body_t *, void *owner);
+extern void mu_body_destroy       (mu_body_t *, void *owner);
+extern void * mu_body_get_owner   (mu_body_t);
+extern int mu_body_is_modified    (mu_body_t);
+extern int mu_body_clear_modified (mu_body_t);
 
-extern int body_get_stream     __P ((body_t, stream_t *));
-extern int body_set_stream     __P ((body_t, stream_t, void *owner));
+extern int mu_body_get_stream     (mu_body_t, mu_stream_t *);
+extern int mu_body_set_stream     (mu_body_t, mu_stream_t, void *owner);
 
-extern int body_get_filename   __P ((body_t, char *, size_t, size_t *));
+extern int mu_body_get_filename   (mu_body_t, char *, size_t, size_t *);
 
-extern int body_size           __P ((body_t, size_t*));
-extern int body_set_size       __P ((body_t, int (*_size)
-				     __PMT ((body_t, size_t*)), void *owner));
-extern int body_lines          __P ((body_t, size_t *));
-extern int body_set_lines      __P ((body_t, int (*_lines)
-				     __PMT ((body_t, size_t*)), void *owner));
+extern int mu_body_size           (mu_body_t, size_t *);
+extern int mu_body_set_size       (mu_body_t,
+				int (*_size) (mu_body_t, size_t*), void *owner);
+extern int mu_body_lines          (mu_body_t, size_t *);
+extern int mu_body_set_lines      (mu_body_t,
+				int (*_lines) (mu_body_t, size_t*), void *owner);
 
 #ifdef __cplusplus
 }
