@@ -17,23 +17,18 @@
 #ifndef MUASPRINTF_H
 #define MUASPRINTF_H
 
-#ifndef __P
-# if defined PROTOTYPES || (defined __STDC__ && __STDC__)
-#  define __P(args) args
-# else
-#  define __P(args) ()
-# endif
-#endif /*__P */
-
+#ifndef _GNU_SOURCE
+# define _GNU_SOURCE
+#endif
 #include <stdarg.h>
 #include <stdio.h>
 
 #if !HAVE_DECL_VASPRINTF
-extern int vasprintf __P((char **result, const char *format, va_list args));
+extern int vasprintf (char **result, const char *format, va_list args);
 #endif
 #if !HAVE_DECL_ASPRINTF
 #if __STDC__
-extern int asprintf __P((char **result, const char *format, ...));
+extern int asprintf (char **result, const char *format, ...);
 #else
 extern int asprintf ();
 #endif
