@@ -1,6 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
    Copyright (C) 1999, 2000, 2001, 2002, 2004, 
-   2005 Free Software Foundation, Inc.
+   2005, 2006 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -84,7 +84,7 @@ sieve_code_number (long num)
 }
 
 int
-sieve_code_string (char *string)
+sieve_code_string (const char *string)
 {
   sieve_op_t op;
 
@@ -194,6 +194,14 @@ sieve_code_command (mu_sieve_register_t *reg, mu_list_t arglist)
 	      if (tag->argtype != SVT_VOID)
 		{
 		  mu_iterator_next (itr);
+		  if (mu_iterator_is_done (itr))
+		    {
+		      sieve_compile_error (sieve_filename, sieve_line_num,
+			   _("required argument for tag %s is missing"),
+					   tag->name);
+		      err = 1;
+		      break;
+		    }
 		  mu_iterator_current (itr, (void **)&tagrec.arg);
 		}
 	      else
@@ -330,10 +338,30 @@ sieve_code_line (size_t line)
 	 || sieve_code (&op);
 }
 
+static int sieve_source_changed;
+
+void
+sieve_change_source ()
+{
+  sieve_source_changed = 1;
+}
+
+static int
+sieve_check_source_changed ()
+{
+  if (sieve_source_changed)
+    {
+      sieve_source_changed = 0;
+      return sieve_code_source (sieve_filename);
+    }
+  return 0;
+}
+
 int
 sieve_code_action (mu_sieve_register_t *reg, mu_list_t arglist)
 {
-  return sieve_code_line (sieve_line_num)
+  return sieve_check_source_changed ()
+         || sieve_code_line (sieve_line_num)
          || sieve_code_instr (instr_action)
          || sieve_code_command (reg, arglist);
 }
@@ -341,7 +369,8 @@ sieve_code_action (mu_sieve_register_t *reg, mu_list_t arglist)
 int
 sieve_code_test (mu_sieve_register_t *reg, mu_list_t arglist)
 {
-  return sieve_code_line (sieve_line_num)
+  return sieve_check_source_changed ()
+         || sieve_code_line (sieve_line_num)
          || sieve_code_instr (instr_test)
          || sieve_code_command (reg, arglist);
 }
