@@ -13,7 +13,8 @@
 
    You should have received a copy of the GNU General Public License
    along with GNU Mailutils; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+   MA 02110-1301 USA */
 
 #include <mail.local.h>
 
@@ -40,20 +41,18 @@ mu_debug_t mudebug;        /* Mailutils debugging object */
 #define MAXFD 64
 #define EX_QUOTA() (ex_quota_tempfail ? EX_TEMPFAIL : EX_UNAVAILABLE)
 
-void close_fds __P((void));
-int make_tmp __P((const char *from, mailbox_t *mbx));
-void deliver __P((mailbox_t msg, char *name));
-void guess_retval __P((int ec));
-void mailer_err __P((char *fmt, ...));
-void notify_biff __P((mailbox_t mbox, char *name, size_t size));
+void close_fds (void);
+int make_tmp (const char *from, mu_mailbox_t *mbx);
+void deliver (mu_mailbox_t msg, char *name);
+void guess_retval (int ec);
+void mailer_err (char *fmt, ...);
+void notify_biff (mu_mailbox_t mbox, char *name, size_t size);
 
 const char *program_version = "mail.local (" PACKAGE_STRING ")";
 static char doc[] =
-/* TRANSLATORS: Please, preserve the vertical tabulation (^K character)
-   in this message */
-N_("GNU mail.local -- the local MDA\
-\v\
-Debug flags are:\n\
+N_("GNU mail.local -- the local MDA")
+"\v"
+N_("Debug flags are:\n\
   g - guimb stack traces\n\
   T - mailutils traces (MU_DEBUG_TRACE)\n\
   P - network protocols (MU_DEBUG_PROT)\n\
@@ -245,18 +244,18 @@ _sieve_debug_printer (void *unused, const char *fmt, va_list ap)
 
 static void
 _sieve_action_log (void *user_name,
-		   const sieve_locus_t *locus, size_t msgno, message_t msg,
+		   const mu_sieve_locus_t *locus, size_t msgno, mu_message_t msg,
 		   const char *action, const char *fmt, va_list ap)
 {
   char *text = NULL;
   
   if (message_id_header)
     {
-      header_t hdr = NULL;
+      mu_header_t hdr = NULL;
       char *val = NULL;
-      message_get_header (msg, &hdr);
-      if (header_aget_value (hdr, message_id_header, &val) == 0
-	  || header_aget_value (hdr, MU_HEADER_MESSAGE_ID, &val) == 0)
+      mu_message_get_header (msg, &hdr);
+      if (mu_header_aget_value (hdr, message_id_header, &val) == 0
+	  || mu_header_aget_value (hdr, MU_HEADER_MESSAGE_ID, &val) == 0)
 	{
 	  asprintf (&text, _("%s:%lu: %s on msg %s"),
 		    locus->source_file,
@@ -268,7 +267,7 @@ _sieve_action_log (void *user_name,
   if (text == NULL)
     {
       size_t uid = 0;
-      message_get_uid (msg, &uid);
+      mu_message_get_uid (msg, &uid);
       asprintf (&text, _("%s:%lu: %s on msg uid %d"),
 		locus->source_file,
 		(unsigned long)	locus->source_line,
@@ -309,7 +308,7 @@ _sieve_parse_error (void *user_name, const char *filename, int lineno,
 int
 main (int argc, char *argv[])
 {
-  mailbox_t mbox = NULL;
+  mu_mailbox_t mbox = NULL;
   int arg_index;
   
   /* Preparative work: close inherited fds, force a reasonable umask
@@ -321,17 +320,17 @@ main (int argc, char *argv[])
   mu_init_nls ();
 
   /* Default locker settings */
-  locker_set_default_flags (MU_LOCKER_PID|MU_LOCKER_RETRY,
-			    mu_locker_set_flags);
-  locker_set_default_retry_timeout (1);
-  locker_set_default_retry_count (300);
+  mu_locker_set_default_flags (MU_LOCKER_PID|MU_LOCKER_RETRY,
+			    mu_locker_assign);
+  mu_locker_set_default_retry_timeout (1);
+  mu_locker_set_default_retry_count (300);
 
   /* Default error code for command line errors */
   mu_argp_error_code = EX_CONFIG;
   /* Register needed modules */
   MU_AUTH_REGISTER_ALL_MODULES();
   mu_argp_init (program_version, NULL);
-  sieve_argp_init ();
+  mu_sieve_argp_init ();
   /* Parse command line */
   mu_argp_parse (&argp, &argc, &argv, 0, argp_capa, &arg_index, NULL);
   
@@ -372,15 +371,11 @@ main (int argc, char *argv[])
     }
 
   /* Register local mbox formats. */
-  {
-    list_t bookie;
-    registrar_get_list (&bookie);
-    list_append (bookie, mbox_record); 
-    list_append (bookie, path_record);
-    /* Possible supported mailers.  */
-    list_append (bookie, sendmail_record);
-    list_append (bookie, smtp_record);
-  }
+  mu_registrar_record (mu_mbox_record); 
+  mu_registrar_record (mu_path_record);
+  /* Possible supported mailers.  */
+  mu_registrar_record (mu_sendmail_record);
+  mu_registrar_record (mu_smtp_record);
 
   if (make_tmp (from, &mbox))
     exit (exit_code);
@@ -407,7 +402,7 @@ main (int argc, char *argv[])
 }
 
 int
-sieve_test (struct mu_auth_data *auth, mailbox_t mbx)
+sieve_test (struct mu_auth_data *auth, mu_mailbox_t mbx)
 {
   int rc = 1;
   char *progfile;
@@ -423,8 +418,8 @@ sieve_test (struct mu_auth_data *auth, mailbox_t mbx)
     }
   else
     {
-      sieve_machine_t mach;
-      rc = sieve_machine_init (&mach, auth->name);
+      mu_sieve_machine_t mach;
+      rc = mu_sieve_machine_init (&mach, auth->name);
       if (rc)
 	{
 	  mu_error (_("Cannot initialize sieve machine: %s"),
@@ -432,33 +427,33 @@ sieve_test (struct mu_auth_data *auth, mailbox_t mbx)
 	}
       else
 	{
-	  sieve_set_debug (mach, _sieve_debug_printer);
-	  sieve_set_debug_level (mach, mudebug, sieve_debug_flags);
-	  sieve_set_parse_error (mach, _sieve_parse_error);
+	  mu_sieve_set_debug (mach, _sieve_debug_printer);
+	  mu_sieve_set_debug_level (mach, mudebug, sieve_debug_flags);
+	  mu_sieve_set_parse_error (mach, _sieve_parse_error);
 	  if (sieve_enable_log)
-	    sieve_set_logger (mach, _sieve_action_log);
+	    mu_sieve_set_logger (mach, _sieve_action_log);
 	  
-	  rc = sieve_compile (mach, progfile);
+	  rc = mu_sieve_compile (mach, progfile);
 	  if (rc == 0)
 	    {
-	      attribute_t attr;
-	      message_t msg = NULL;
+	      mu_attribute_t attr;
+	      mu_message_t msg = NULL;
 		
-	      mailbox_get_message (mbx, 1, &msg);
-	      message_get_attribute (msg, &attr);
-	      attribute_unset_deleted (attr);
+	      mu_mailbox_get_message (mbx, 1, &msg);
+	      mu_message_get_attribute (msg, &attr);
+	      mu_attribute_unset_deleted (attr);
 	      if (switch_user_id (auth, 1) == 0)
 		{
 		  chdir (auth->dir);
 		
-		  rc = sieve_message (mach, msg);
+		  rc = mu_sieve_message (mach, msg);
 		  if (rc == 0)
-		    rc = attribute_is_deleted (attr) == 0;
+		    rc = mu_attribute_is_deleted (attr) == 0;
 
 		  switch_user_id (auth, 0);
 		  chdir ("/");
 		}
-	      sieve_machine_destroy (&mach);
+	      mu_sieve_machine_destroy (&mach);
 	    }
 	}
     }
@@ -467,7 +462,7 @@ sieve_test (struct mu_auth_data *auth, mailbox_t mbx)
 }
 
 int
-mda (mailbox_t mbx, char *username)
+mda (mu_mailbox_t mbx, char *username)
 {
   deliver (mbx, username);
 
@@ -523,10 +518,10 @@ switch_user_id (struct mu_auth_data *auth, int user)
 }
 
 static int
-tmp_write (stream_t stream, off_t *poffset, char *buf, size_t len)
+tmp_write (mu_stream_t stream, mu_off_t *poffset, char *buf, size_t len)
 {
   size_t n = 0;
-  int status = stream_write (stream, buf, len, *poffset, &n);
+  int status = mu_stream_write (stream, buf, len, *poffset, &n);
   if (status == 0 && n != len)
     status = EIO;
   *poffset += n;
@@ -534,25 +529,25 @@ tmp_write (stream_t stream, off_t *poffset, char *buf, size_t len)
 }
 
 int
-make_tmp (const char *from, mailbox_t *mbox)
+make_tmp (const char *from, mu_mailbox_t *mbox)
 {
-  stream_t stream;
+  mu_stream_t stream;
   char *buf = NULL;
   size_t n = 0;
-  off_t offset = 0;
+  mu_off_t offset = 0;
   size_t line;
   int status;
   static char *newline = "\n";
   char *tempfile;
   
   tempfile = mu_tempname (NULL);
-  if ((status = file_stream_create (&stream, tempfile, MU_STREAM_RDWR)))
+  if ((status = mu_file_stream_create (&stream, tempfile, MU_STREAM_RDWR)))
     {
       mailer_err (_("Unable to open temporary file: %s"), mu_strerror (status));
       exit (exit_code);
     }
 
-  if ((status = stream_open (stream)))
+  if ((status = mu_stream_open (stream)))
     {
       mailer_err (_("unable to open temporary file: %s"), mu_strerror (status));
       exit (exit_code);
@@ -604,7 +599,7 @@ make_tmp (const char *from, mailbox_t *mbox)
       if (status)
 	{
 	  mailer_err (_("Error writing temporary file: %s"), mu_strerror (status));
-	  stream_destroy (&stream, stream_get_owner (stream));
+	  mu_stream_destroy (&stream, mu_stream_get_owner (stream));
 	  return status;
 	}
     }
@@ -621,27 +616,27 @@ make_tmp (const char *from, mailbox_t *mbox)
     {
       errno = status;
       mailer_err (_("Error writing temporary file: %s"), mu_strerror (status));
-      stream_destroy (&stream, stream_get_owner (stream));
+      mu_stream_destroy (&stream, mu_stream_get_owner (stream));
       return status;
     }
 
-  stream_flush (stream);
-  if ((status = mailbox_create (mbox, "/dev/null")) 
-      || (status = mailbox_open (*mbox, MU_STREAM_READ))
-      || (status = mailbox_set_stream (*mbox, stream)))
+  mu_stream_flush (stream);
+  if ((status = mu_mailbox_create (mbox, "/dev/null")) 
+      || (status = mu_mailbox_open (*mbox, MU_STREAM_READ))
+      || (status = mu_mailbox_set_stream (*mbox, stream)))
     {
       mailer_err (_("Error opening temporary file: %s"), mu_strerror (status));
-      stream_destroy (&stream, stream_get_owner (stream));
+      mu_stream_destroy (&stream, mu_stream_get_owner (stream));
       return status;
     }
 
-  status = mailbox_messages_count (*mbox, &n);
+  status = mu_mailbox_messages_count (*mbox, &n);
   if (status)
     {
       errno = status;
       mailer_err (_("Error creating temporary message: %s"),
 		  mu_strerror (status));
-      stream_destroy (&stream, stream_get_owner (stream));
+      mu_stream_destroy (&stream, mu_stream_get_owner (stream));
       return status;
     }
 
@@ -649,16 +644,16 @@ make_tmp (const char *from, mailbox_t *mbox)
 }
 
 void
-deliver (mailbox_t imbx, char *name)
+deliver (mu_mailbox_t imbx, char *name)
 {
-  mailbox_t mbox;
+  mu_mailbox_t mbox;
   char *path;
-  url_t url = NULL;
-  locker_t lock;
+  mu_url_t url = NULL;
+  mu_locker_t lock;
   struct mu_auth_data *auth;
   int status;
-  stream_t istream, ostream;
-  off_t size;
+  mu_stream_t istream, ostream;
+  mu_off_t size;
   int failed = 0;
   
   auth = mu_get_auth_by_name (name);
@@ -676,7 +671,7 @@ deliver (mailbox_t imbx, char *name)
       return;
     }
 
-  if ((status = mailbox_get_stream (imbx, &istream)) != 0)
+  if ((status = mu_mailbox_get_stream (imbx, &istream)) != 0)
     {
       mailer_err (_("Cannot get input message stream: %s"),
 		  mu_strerror (status));
@@ -684,7 +679,7 @@ deliver (mailbox_t imbx, char *name)
       return;
     }
   
-  if ((status = mailbox_create (&mbox, auth->mailbox)) != 0)
+  if ((status = mu_mailbox_create (&mbox, auth->mailbox)) != 0)
     {
       mailer_err (_("Cannot open mailbox %s: %s"),
 		  auth->mailbox, mu_strerror (status));
@@ -692,56 +687,57 @@ deliver (mailbox_t imbx, char *name)
       return;
     }
 
-  mailbox_get_url (mbox, &url);
-  path = (char*) url_to_string (url);
+  mu_mailbox_get_url (mbox, &url);
+  path = (char*) mu_url_to_string (url);
 
   /* Actually open the mailbox. Switch to the user's euid to make
      sure the maildrop file will have right privileges, in case it
      will be created */
   if (switch_user_id (auth, 1))
     return;
-  status = mailbox_open (mbox, MU_STREAM_RDWR|MU_STREAM_CREAT);
+  status = mu_mailbox_open (mbox, MU_STREAM_RDWR|MU_STREAM_CREAT);
   if (switch_user_id (auth, 0))
     return;
   if (status != 0)
     {
       mailer_err (_("Cannot open mailbox %s: %s"), path, mu_strerror (status));
-      mailbox_destroy (&mbox);
+      mu_mailbox_destroy (&mbox);
       return;
     }
   
-  mailbox_get_locker (mbox, &lock);
+  mu_mailbox_get_locker (mbox, &lock);
 
-  status = locker_lock (lock);
+  status = mu_locker_lock (lock);
 
   if (status)
     {
-      mailer_err (_("Cannot lock mailbox `%s': %s"), path, mu_strerror (status));
-      mailbox_destroy (&mbox);
+      mailer_err (_("Cannot lock mailbox `%s': %s"), path,
+		  mu_strerror (status));
+      mu_mailbox_destroy (&mbox);
       exit_code = EX_TEMPFAIL;
       return;
     }
 
-  if ((status = mailbox_get_stream (mbox, &ostream)))
+  if ((status = mu_mailbox_get_stream (mbox, &ostream)))
     {
       mailer_err (_("Cannot get stream for mailbox %s: %s"),
 		  path, mu_strerror (status));
-      mailbox_destroy (&mbox);
+      mu_mailbox_destroy (&mbox);
       return;
     }
 
-  if ((status = stream_size (ostream, &size)))
+  if ((status = mu_stream_size (ostream, &size)))
     {
       mailer_err (_("Cannot get stream size (mailbox %s): %s"),
 		  path, mu_strerror (status));
-      mailbox_destroy (&mbox);
+      mu_mailbox_destroy (&mbox);
       return;
     }
 
 #if defined(USE_MAILBOX_QUOTAS)
   {
     size_t n;
-    off_t isize;
+    mu_off_t isize;
 
     switch (check_quota (name, size, &n))
       {
@@ -755,7 +751,7 @@ deliver (mailbox_t imbx, char *name)
 	break;
 	
       default:
-	if ((status = stream_size (istream, &isize)))
+	if ((status = mu_stream_size (istream, &isize)))
 	  {
 	    mailer_err (_("Cannot get stream size (input message): %s"),
 			path, mu_strerror (status));
@@ -776,13 +772,13 @@ deliver (mailbox_t imbx, char *name)
   
   if (!failed && switch_user_id (auth, 1) == 0)
     {
-      off_t ioff = 0;
-      off_t off = size;
+      mu_off_t ioff = 0;
+      mu_off_t off = size;
       size_t nwr, nrd;
       char *buf = NULL;
-      off_t bufsize = 1024;
+      mu_off_t bufsize = 1024;
 
-      stream_size (istream, &bufsize);
+      mu_stream_size (istream, &bufsize);
       for (; (buf = malloc (bufsize)) == NULL && bufsize > 1; bufsize /= 2)
 	;
       
@@ -795,11 +791,11 @@ deliver (mailbox_t imbx, char *name)
 	{
 	  status = 0;
 
-	  while ((status = stream_read (istream, buf, bufsize, ioff, &nrd))
+	  while ((status = mu_stream_read (istream, buf, bufsize, ioff, &nrd))
 		 == 0
 		 && nrd > 0)
 	    {
-	      status = stream_write (ostream, buf, nrd, off, &nwr);
+	      status = mu_stream_write (ostream, buf, nrd, off, &nwr);
 	      if (status)
 		break;
 	      ioff += nrd;
@@ -815,7 +811,7 @@ deliver (mailbox_t imbx, char *name)
 	{
 	  /* Undo the delivery by truncating the mailbox back to its
 	     original size */
-	  int rc = stream_truncate (ostream, size);
+	  int rc = mu_stream_truncate (ostream, size);
 	  if (rc)
 	    mailer_err (_("Error writing to mailbox: %s. Mailbox NOT truncated: %s"),
 			mu_strerror (status), mu_strerror (rc));
@@ -828,18 +824,18 @@ deliver (mailbox_t imbx, char *name)
   if (!failed)
     notify_biff (mbox, name, size);
 
-  locker_unlock (lock);
+  mu_locker_unlock (lock);
 
   mu_auth_data_free (auth);
-  mailbox_close (mbox);
-  mailbox_destroy (&mbox);
+  mu_mailbox_close (mbox);
+  mu_mailbox_destroy (&mbox);
 }
 
 void
-notify_biff (mailbox_t mbox, char *name, size_t size)
+notify_biff (mu_mailbox_t mbox, char *name, size_t size)
 {
   static int fd = -1;
-  url_t url = NULL;
+  mu_url_t url = NULL;
   char *buf = NULL;
   static struct sockaddr_in inaddr;
     
@@ -862,8 +858,9 @@ notify_biff (mailbox_t mbox, char *name, size_t size)
   if (fd < 0)
     return;
   
-  mailbox_get_url (mbox, &url);
-  asprintf (&buf, "%s@%ld:%s", name, size, url_to_string (url));
+  mu_mailbox_get_url (mbox, &url);
+  asprintf (&buf, "%s@%lu:%s", name,
+	    (unsigned long) size, mu_url_to_string (url));
   if (buf)
     {
       sendto (fd, buf, strlen (buf), 0, (struct sockaddr *)&inaddr,
