@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2001, 2002, 2003 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2001, 2002, 2003, 2005 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -26,11 +26,16 @@ int
 mail_eq (int argc, char **argv)
 {
   msgset_t *list = NULL;
-    
+  size_t n;
+
   switch (argc)
     {
     case 1:
-      fprintf (ofile, "%d\n", cursor);
+      n = get_cursor ();
+      if (n == 0)
+        util_error (_("No applicable message"));
+      else
+        fprintf (ofile, "%u\n", n);
       break;
 
     case 2:
@@ -38,8 +43,8 @@ mail_eq (int argc, char **argv)
 	{
 	  if (list->msg_part[0] <= total)
 	    {
-	      cursor = list->msg_part[0];
-	      fprintf (ofile, "%d\n", cursor);
+	      set_cursor (list->msg_part[0]);
+	      fprintf (ofile, "%u\n", list->msg_part[0]);
 	    }
 	  else
 	    util_error_range (list->msg_part[0]);
