@@ -19,7 +19,7 @@
 #include "mail.h"
 
 void
-make_in_reply_to (compose_env_t *env, message_t msg)
+make_in_reply_to (compose_env_t *env, mu_message_t msg)
 {
   char *value = NULL;
 
@@ -30,7 +30,7 @@ make_in_reply_to (compose_env_t *env, message_t msg)
 }
 
 void
-make_references (compose_env_t *env, message_t msg)
+make_references (compose_env_t *env, mu_message_t msg)
 {
   char *value = NULL;
 
@@ -47,18 +47,18 @@ make_references (compose_env_t *env, message_t msg)
  */
 
 int
-reply0 (msgset_t *mspec, message_t msg, void *data)
+reply0 (msgset_t *mspec, mu_message_t msg, void *data)
 {
-  header_t hdr;
+  mu_header_t hdr;
   compose_env_t env;
   int status;
   char *str;
 
-  cursor = mspec->msg_part[0];
+  set_cursor (mspec->msg_part[0]);
   
   compose_init (&env);
 
-  message_get_header (msg, &hdr);
+  mu_message_get_header (msg, &hdr);
 
   compose_header_set (&env, MU_HEADER_TO,
 		      util_get_sender (mspec->msg_part[0], 0),
@@ -68,21 +68,21 @@ reply0 (msgset_t *mspec, message_t msg, void *data)
     {
       /* Add all recepients of the originate letter */
 
-      address_t addr = NULL;
+      mu_address_t addr = NULL;
       size_t i, count = 0;
       char buf[512];
 
-      if (header_aget_value (hdr, MU_HEADER_TO, &str) == 0)
+      if (mu_header_aget_value (hdr, MU_HEADER_TO, &str) == 0)
 	{
-	  address_create (&addr, str);
+	  mu_address_create (&addr, str);
 	  free (str);
-	  address_get_count (addr, &count);
+	  mu_address_get_count (addr, &count);
 	}
 
       /* Make sure we do not include our alternate names */
       for (i = 1; i <= count; i++)
 	{
-	  address_get_email (addr, i, buf, sizeof (buf), NULL);
+	  mu_address_get_email (addr, i, buf, sizeof (buf), NULL);
 	  if ((util_getenv (NULL, "metoo", Mail_env_boolean, 0) == 0)
 	      || !mail_is_my_name (buf))
 	    compose_header_set (&env, MU_HEADER_TO,
@@ -91,15 +91,15 @@ reply0 (msgset_t *mspec, message_t msg, void *data)
 	}
       
       /* Finally, add any Ccs */
-      if (header_aget_value (hdr, MU_HEADER_CC, &str) == 0)
+      if (mu_header_aget_value (hdr, MU_HEADER_CC, &str) == 0)
 	compose_header_set (&env, MU_HEADER_TO, str, COMPOSE_SINGLE_LINE);
     }
 
-  if (header_aget_value (hdr, MU_HEADER_SUBJECT, &str) == 0)
+  if (mu_header_aget_value (hdr, MU_HEADER_SUBJECT, &str) == 0)
     {
       char *p = NULL;
       
-      if (munre_subject (str, NULL))
+      if (mu_unre_subject (str, NULL))
 	util_strcat (&p, util_reply_prefix ());
       util_strcat (&p, str);
       free (str);
