@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2005, 2006 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -11,9 +11,10 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Lesser General Public
-   License along with this library; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   You should have received a copy of the GNU Lesser General
+   Public License along with this library; if not, write to the
+   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301 USA */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -37,7 +38,7 @@
 
 /* Get email addresses from rfc822 address.  */
 int
-address_create (address_t * a, const char *s)
+mu_address_create (mu_address_t * a, const char *s)
 {
   /* 'a' must exist, and can't already have been initialized
    */
@@ -50,7 +51,7 @@ address_create (address_t * a, const char *s)
     return EINVAL;
 
   *a = NULL;
-  status = parse822_address_list (a, s);
+  status = mu_parse822_address_list (a, s);
   if (status == 0)
     {
       /* And address-list may contain 0 addresses but parse correctly.
@@ -61,7 +62,7 @@ address_create (address_t * a, const char *s)
       (*a)->addr = strdup (s);
       if (!(*a)->addr)
 	{
-	  address_destroy (a);
+	  mu_address_destroy (a);
 	  return ENOMEM;
 	}
     }
@@ -70,7 +71,7 @@ address_create (address_t * a, const char *s)
 
 /* Get email addresses from array of rfc822 addresses. */
 int
-address_createv (address_t * a, const char *sv[], size_t len)
+mu_address_createv (mu_address_t * a, const char *sv[], size_t len)
 {
   int status = 0;
   size_t buflen = 0;
@@ -120,7 +121,7 @@ address_createv (address_t * a, const char *sv[], size_t len)
 	strcat (buf, sv[i]);
     }
 
-  status = address_create (a, buf);
+  status = mu_address_create (a, buf);
 
   free (buf);
 
@@ -128,12 +129,12 @@ address_createv (address_t * a, const char *sv[], size_t len)
 }
 
 void
-address_destroy (address_t * paddress)
+mu_address_destroy (mu_address_t * paddress)
 {
   if (paddress && *paddress)
     {
-      address_t address = *paddress;
-      address_t current;
+      mu_address_t address = *paddress;
+      mu_address_t current;
       for (; address; address = current)
 	{
 	  if (address->addr)
@@ -158,7 +159,7 @@ address_destroy (address_t * paddress)
 }
 
 int
-address_concatenate (address_t to, address_t * from)
+mu_address_concatenate (mu_address_t to, mu_address_t * from)
 {
   if (!to || !from || !*from)
     return EINVAL;
@@ -190,8 +191,8 @@ address_concatenate (address_t to, address_t * from)
   return 0;
 }
 
-address_t 
-_address_get_nth (address_t addr, size_t no)
+mu_address_t 
+_address_get_nth (mu_address_t addr, size_t no)
 {
   int i;
   
@@ -202,21 +203,21 @@ _address_get_nth (address_t addr, size_t no)
 }
 
 int
-address_get_nth (address_t addr, size_t no, address_t *pret)
+mu_address_get_nth (mu_address_t addr, size_t no, mu_address_t *pret)
 {
-  address_t subaddr = _address_get_nth (addr, no);
+  mu_address_t subaddr = _address_get_nth (addr, no);
   if (!subaddr)
     return MU_ERR_NOENT;
-  *pret = address_dup (subaddr);
+  *pret = mu_address_dup (subaddr);
   return 0;
 }
 
 int
-address_get_personal (address_t addr, size_t no, char *buf, size_t len,
-		      size_t * n)
+mu_address_get_personal (mu_address_t addr, size_t no, char *buf, size_t len,
+			 size_t * n)
 {
   size_t i;
-  address_t subaddr;
+  mu_address_t subaddr;
   
   if (addr == NULL)
     return EINVAL;
@@ -232,11 +233,34 @@ address_get_personal (address_t addr, size_t no, char *buf, size_t len,
 }
 
 int
-address_get_comments (address_t addr, size_t no, char *buf, size_t len,
-		      size_t * n)
+mu_address_set_personal (mu_address_t addr, size_t no, const char *buf)
+{
+  char *s;
+  mu_address_t subaddr;
+  
+  if (addr == NULL)
+    return EINVAL;
+
+  subaddr = _address_get_nth (addr, no);
+  if (!subaddr)
+    return MU_ERR_NOENT;
+
+  s = strdup (buf);
+  if (!s)
+    return errno;
+  
+  free (subaddr->personal);
+  subaddr->personal = s;
+
+  return 0;
+}
+
+int
+mu_address_get_comments (mu_address_t addr, size_t no, char *buf, size_t len,
+			 size_t * n)
 {
   size_t i;
-  address_t subaddr;
+  mu_address_t subaddr;
   
   if (addr == NULL)
     return EINVAL;
@@ -252,11 +276,34 @@ address_get_comments (address_t addr, size_t no, char *buf, size_t len,
 }
 
 int
-address_get_email (address_t addr, size_t no, char *buf, size_t len,
-		   size_t * n)
+mu_address_set_comments (mu_address_t addr, size_t no, const char *buf)
+{
+  char *s;
+  mu_address_t subaddr;
+  
+  if (addr == NULL)
+    return EINVAL;
+
+  subaddr = _address_get_nth (addr, no);
+  if (!subaddr)
+    return MU_ERR_NOENT;
+
+  s = strdup (buf);
+  if (!s)
+    return errno;
+  
+  free (subaddr->comments);
+  subaddr->comments = s;
+
+  return 0;
+}
+
+int
+mu_address_get_email (mu_address_t addr, size_t no, char *buf, size_t len,
+		      size_t * n)
 {
   size_t i;
-  address_t subaddr;
+  mu_address_t subaddr;
 
   if (addr == NULL)
     return EINVAL;
@@ -293,7 +340,7 @@ address_get_email (address_t addr, size_t no, char *buf, size_t len,
 } while (0)
      
 size_t
-address_format_string (address_t addr, char *buf, size_t buflen)
+mu_address_format_string (mu_address_t addr, char *buf, size_t buflen)
 {
   int rc = 0;
   int comma = 0;
@@ -338,10 +385,10 @@ address_format_string (address_t addr, char *buf, size_t buflen)
 }
 
 int
-address_aget_personal (address_t addr, size_t no, char **buf)
+mu_address_aget_personal (mu_address_t addr, size_t no, char **buf)
 {
   int status = 0;
-  address_t subaddr;
+  mu_address_t subaddr;
   
   if (addr == NULL)
     return EINVAL;
@@ -362,10 +409,10 @@ address_aget_personal (address_t addr, size_t no, char **buf)
 }
 
 int
-address_aget_comments (address_t addr, size_t no, char **buf)
+address_aget_comments (mu_address_t addr, size_t no, char **buf)
 {
   int status = 0;
-  address_t subaddr;
+  mu_address_t subaddr;
   
   if (addr == NULL)
     return EINVAL;
@@ -386,10 +433,10 @@ address_aget_comments (address_t addr, size_t no, char **buf)
 }
 
 int
-address_aget_email (address_t addr, size_t no, char **buf)
+mu_address_aget_email (mu_address_t addr, size_t no, char **buf)
 {
   int status = 0;
-  address_t subaddr;
+  mu_address_t subaddr;
   
   if (addr == NULL || buf == NULL)
     return EINVAL;
@@ -411,10 +458,10 @@ address_aget_email (address_t addr, size_t no, char **buf)
 }
 
 int
-address_aget_local_part (address_t addr, size_t no, char **buf)
+mu_address_aget_local_part (mu_address_t addr, size_t no, char **buf)
 {
   int status = 0;
-  address_t subaddr;
+  mu_address_t subaddr;
   
   if (addr == NULL || buf == NULL)
     return EINVAL;
@@ -436,10 +483,10 @@ address_aget_local_part (address_t addr, size_t no, char **buf)
 }
 
 int
-address_aget_domain (address_t addr, size_t no, char **buf)
+mu_address_aget_domain (mu_address_t addr, size_t no, char **buf)
 {
   int status = 0;
-  address_t subaddr;
+  mu_address_t subaddr;
   
   if (addr == NULL || buf == NULL)
     return EINVAL;
@@ -461,11 +508,11 @@ address_aget_domain (address_t addr, size_t no, char **buf)
 }
 
 int
-address_get_local_part (address_t addr, size_t no, char *buf, size_t len,
-			size_t * n)
+mu_address_get_local_part (mu_address_t addr, size_t no, char *buf, size_t len,
+			   size_t * n)
 {
   size_t i;
-  address_t subaddr;
+  mu_address_t subaddr;
   
   if (addr == NULL)
     return EINVAL;
@@ -481,11 +528,11 @@ address_get_local_part (address_t addr, size_t no, char *buf, size_t len,
 }
 
 int
-address_get_domain (address_t addr, size_t no, char *buf, size_t len,
-		    size_t * n)
+mu_address_get_domain (mu_address_t addr, size_t no, char *buf, size_t len,
+		       size_t * n)
 {
   size_t i;
-  address_t subaddr;
+  mu_address_t subaddr;
   
   if (addr == NULL)
     return EINVAL;
@@ -501,11 +548,11 @@ address_get_domain (address_t addr, size_t no, char *buf, size_t len,
 }
 
 int
-address_get_route (address_t addr, size_t no, char *buf, size_t len,
-		   size_t * n)
+mu_address_get_route (mu_address_t addr, size_t no, char *buf, size_t len,
+		      size_t * n)
 {
   size_t i;
-  address_t subaddr;
+  mu_address_t subaddr;
   
   if (addr == NULL)
     return EINVAL;
@@ -521,7 +568,7 @@ address_get_route (address_t addr, size_t no, char *buf, size_t len,
 }
 
 static int
-_address_is_group (address_t addr)
+_address_is_group (mu_address_t addr)
 {
   if (addr->personal && !addr->local_part && !addr->domain)
     return 1;
@@ -529,7 +576,7 @@ _address_is_group (address_t addr)
 }
 
 static int
-_address_is_email (address_t addr)
+_address_is_email (mu_address_t addr)
 {
   if (addr->email)
     return 1;
@@ -537,7 +584,7 @@ _address_is_email (address_t addr)
 }
 
 static int
-_address_is_unix_mailbox (address_t addr)
+_address_is_unix_mailbox (mu_address_t addr)
 {
   if (addr->local_part && !addr->email)
     return 1;
@@ -545,9 +592,9 @@ _address_is_unix_mailbox (address_t addr)
 }
 
 int
-address_is_group (address_t addr, size_t no, int *yes)
+mu_address_is_group (mu_address_t addr, size_t no, int *yes)
 {
-  address_t subaddr;
+  mu_address_t subaddr;
   
   if (addr == NULL)
     return EINVAL;
@@ -562,7 +609,7 @@ address_is_group (address_t addr, size_t no, int *yes)
 }
 
 int
-address_to_string (address_t addr, char *buf, size_t len, size_t * n)
+mu_address_to_string (mu_address_t addr, char *buf, size_t len, size_t * n)
 {
   size_t i;
   if (addr == NULL)
@@ -572,11 +619,11 @@ address_to_string (address_t addr, char *buf, size_t len, size_t * n)
 
   if (!addr->addr)
     {
-      i = address_format_string (addr, NULL, 0);
+      i = mu_address_format_string (addr, NULL, 0);
       addr->addr = malloc (i + 1);
       if (!addr->addr)
 	return ENOMEM;
-      address_format_string (addr, addr->addr, i+1);
+      mu_address_format_string (addr, addr->addr, i+1);
     }
       
   i = mu_cpystr (buf, addr->addr, len);
@@ -586,7 +633,7 @@ address_to_string (address_t addr, char *buf, size_t len, size_t * n)
 }
 
 int
-address_get_count (address_t addr, size_t * pcount)
+mu_address_get_count (mu_address_t addr, size_t * pcount)
 {
   size_t j;
   for (j = 0; addr; addr = addr->next, j++)
@@ -597,7 +644,7 @@ address_get_count (address_t addr, size_t * pcount)
 }
 
 int
-address_get_group_count (address_t addr, size_t * pcount)
+mu_address_get_group_count (mu_address_t addr, size_t * pcount)
 {
   size_t j;
   for (j = 0; addr; addr = addr->next)
@@ -611,7 +658,7 @@ address_get_group_count (address_t addr, size_t * pcount)
 }
 
 int
-address_get_email_count (address_t addr, size_t * pcount)
+mu_address_get_email_count (mu_address_t addr, size_t * pcount)
 {
   size_t j;
   for (j = 0; addr; addr = addr->next)
@@ -625,7 +672,7 @@ address_get_email_count (address_t addr, size_t * pcount)
 }
 
 int
-address_get_unix_mailbox_count (address_t addr, size_t * pcount)
+mu_address_get_unix_mailbox_count (mu_address_t addr, size_t * pcount)
 {
   size_t j;
   for (j = 0; addr; addr = addr->next)
@@ -639,7 +686,7 @@ address_get_unix_mailbox_count (address_t addr, size_t * pcount)
 }
 
 int
-address_contains_email (address_t addr, const char *email)
+mu_address_contains_email (mu_address_t addr, const char *email)
 {
   for (; addr; addr = addr->next)
     if (strcasecmp (addr->email, email) == 0)
@@ -647,10 +694,10 @@ address_contains_email (address_t addr, const char *email)
   return 0;
 }
 
-address_t
-address_dup (address_t src)
+mu_address_t
+mu_address_dup (mu_address_t src)
 {
-  address_t dst = calloc (1, sizeof (*dst));
+  mu_address_t dst = calloc (1, sizeof (*dst));
 
   if (!dst)
     return NULL;
@@ -672,16 +719,16 @@ address_dup (address_t src)
 }
   
 int
-address_union (address_t *a, address_t b)
+mu_address_union (mu_address_t *a, mu_address_t b)
 {
-  address_t last = NULL;
+  mu_address_t last = NULL;
     
   if (!a || !b)
     return EINVAL;
 
   if (!*a)
     {
-      *a = address_dup (b);
+      *a = mu_address_dup (b);
       if (!*a)
 	return ENOMEM;
       last = *a;
@@ -699,9 +746,9 @@ address_union (address_t *a, address_t b)
     }
 
   for (; b; b = b->next)
-    if (!address_contains_email (*a, b->email))
+    if (!mu_address_contains_email (*a, b->email))
       {
-	address_t next = address_dup (b);
+	mu_address_t next = mu_address_dup (b);
 	if (!next)
 	  return ENOMEM;
 	last->next = next;
