@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2004, 2005 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -11,9 +11,10 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Lesser General Public
-   License along with this library; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   You should have received a copy of the GNU Lesser General
+   Public License along with this library; if not, write to the
+   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301 USA */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -43,6 +44,7 @@
 #include <mailutils/header.h>
 #include <mailutils/message.h>
 #include <mailutils/stream.h>
+#include <mailutils/errno.h>
 
 #define MAX_HDR_LEN 256
 #define BUF_SIZE	2048
@@ -53,31 +55,33 @@ struct _msg_info
   size_t nbytes;
   char *header_buf;
   int header_len;
-  int header_size;
-  header_t hdr;
-  message_t msg;
+  int mu_header_size;
+  mu_header_t hdr;
+  mu_message_t msg;
   int ioffset;
   int ooffset;
-  stream_t stream;		/* output file/decoding stream for saving attachment */
-  stream_t fstream;		/* output file stream for saving attachment */
+  mu_stream_t stream;		/* output file/decoding stream for saving attachment */
+  mu_stream_t fstream;		/* output file stream for saving attachment */
 };
 
 #define MSG_HDR "Content-Type: %s; name=%s\nContent-Transfer-Encoding: %s\nContent-Disposition: attachment; filename=%s\n\n"
 
 int
-message_create_attachment (const char *content_type, const char *encoding,
-			   const char *filename, message_t * newmsg)
+mu_message_create_attachment (const char *content_type, const char *encoding,
+			   const char *filename, mu_message_t * newmsg)
 {
-  header_t hdr;
-  body_t body;
-  stream_t fstream = NULL, tstream = NULL;
+  mu_header_t hdr;
+  mu_body_t body;
+  mu_stream_t fstream = NULL, tstream = NULL;
   char *header, *name = NULL, *fname = NULL;
   int ret;
 
-  if (filename == NULL || newmsg == NULL)
+  if (newmsg == NULL)
+    return MU_ERR_OUT_PTR_NULL;	
+  if (filename == NULL)
     return EINVAL;
 
-  if ((ret = message_create (newmsg, NULL)) == 0)
+  if ((ret = mu_message_create (newmsg, NULL)) == 0)
     {
       if (content_type == NULL)
 	content_type = "text/plain";
@@ -98,23 +102,23 @@ message_create_attachment (const char *content_type, const char *encoding,
 	    {
 	      sprintf (header, MSG_HDR, content_type, name, encoding, name);
 	      if ((ret =
-		   header_create (&hdr, header, strlen (header),
+		   mu_header_create (&hdr, header, strlen (header),
 				  *newmsg)) == 0)
 		{
-		  message_get_body (*newmsg, &body);
+		  mu_message_get_body (*newmsg, &body);
 		  if ((ret =
-		       file_stream_create (&fstream, filename,
+		       mu_file_stream_create (&fstream, filename,
 					   MU_STREAM_READ)) == 0)
 		    {
-		      if ((ret = stream_open (fstream)) == 0)
+		      if ((ret = mu_stream_open (fstream)) == 0)
 			{
 			  if ((ret =
-			       filter_create (&tstream, fstream, encoding,
+			       mu_filter_create (&tstream, fstream, encoding,
 					      MU_FILTER_ENCODE,
 					      MU_STREAM_READ)) == 0)
 			    {
-			      body_set_stream (body, tstream, *newmsg);
-			      message_set_header (*newmsg, hdr, NULL);
+			      mu_body_set_stream (body, tstream, *newmsg);
+			      mu_message_set_header (*newmsg, hdr, NULL);
 			    }
 			}
 		    }
@@ -125,11 +129,11 @@ message_create_attachment (const char *content_type, const char *encoding,
   if (ret)
     {
       if (*newmsg)
-	message_destroy (newmsg, NULL);
+	mu_message_destroy (newmsg, NULL);
       if (hdr)
-	header_destroy (&hdr, NULL);
+	mu_header_destroy (&hdr, NULL);
       if (fstream)
-	stream_destroy (&fstream, NULL);
+	mu_stream_destroy (&fstream, NULL);
       if (fname)
 	free (fname);
     }
@@ -138,16 +142,16 @@ message_create_attachment (const char *content_type, const char *encoding,
 
 
 static int
-_attachment_setup (struct _msg_info **info, message_t msg, stream_t * stream,
+_attachment_setup (struct _msg_info **info, mu_message_t msg, mu_stream_t * stream,
 		   void **data)
 {
   int sfl, ret;
-  body_t body;
+  mu_body_t body;
 
-  if ((ret = message_get_body (msg, &body)) != 0 ||
-      (ret = body_get_stream (body, stream)) != 0)
+  if ((ret = mu_message_get_body (msg, &body)) != 0 ||
+      (ret = mu_body_get_stream (body, stream)) != 0)
     return ret;
-  stream_get_flags (*stream, &sfl);
+  mu_stream_get_flags (*stream, &sfl);
   if (data == NULL && (sfl & MU_STREAM_NONBLOCK))
     return EINVAL;
   if (data)
@@ -175,9 +179,9 @@ _attachment_free (struct _msg_info *info, int free_message)
   if (free_message)
     {
       if (info->msg)
-	message_destroy (&(info->msg), NULL);
+	mu_message_destroy (&(info->msg), NULL);
       else if (info->hdr)
-	header_destroy (&(info->hdr), NULL);
+	mu_header_destroy (&(info->hdr), NULL);
     }
   free (info);
 }
@@ -228,34 +232,34 @@ _header_get_param (char *field_body, const char *param, size_t * len)
 
 #if 0
 int
-message_get_attachment_name (message_t msg, char *name, size_t bufsz, size_t *sz)
+mu_message_get_attachment_name (mu_message_t msg, char *name, size_t bufsz, size_t *sz)
 {
   char *pTmp, *fname = NULL;
-  header_t hdr;
+  mu_header_t hdr;
   int ret = EINVAL;
   size_t size = 0;
 
-  if (filename != NULL && (ret = message_get_header (msg, &hdr)) == 0)
+  if (filename != NULL && (ret = mu_message_get_header (msg, &hdr)) == 0)
     {
       *filename = NULL;
-      header_get_value (hdr, "Content-Disposition", NULL, 0, &size);
+      mu_header_get_value (hdr, "Content-Disposition", NULL, 0, &size);
       if (size)
 	{
 	  if ((pTmp = alloca (size + 1)) == NULL)
 	    ret = ENOMEM;
-	  header_get_value (hdr, "Content-Disposition", pTmp, size + 1, 0);
+	  mu_header_get_value (hdr, "Content-Disposition", pTmp, size + 1, 0);
 	  if (strstr (pTmp, "attachment") != NULL)
 	    fname = _header_get_param (pTmp, "filename", &size);
 	}
       if (fname == NULL)
 	{
 	  size = 0;
-	  header_get_value (hdr, "Content-Type", NULL, 0, &size);
+	  mu_header_get_value (hdr, "Content-Type", NULL, 0, &size);
 	  if (size)
 	    {
 	      if ((pTmp = alloca (size + 1)) == NULL)
 		ret = ENOMEM;
-	      header_get_value (hdr, "Content-Type", pTmp, size + 1, 0);
+	      mu_header_get_value (hdr, "Content-Type", pTmp, size + 1, 0);
 	      fname = _header_get_param (pTmp, "name", &size);
 	    }
 	}
@@ -266,26 +270,26 @@ message_get_attachment_name (message_t msg, char *name, size_t bufsz, size_t *sz
 	    ret = ENOMEM;
 	}
       else
-	ret = ENOENT;
+	ret = MU_ERR_NOENT;
     }
   return ret;
 }
 #endif
 
-int message_aget_attachment_name(message_t msg, char** name)
+int mu_message_aget_attachment_name(mu_message_t msg, char** name)
 {
   size_t sz = 0;
   int ret = 0;
 
-  if(name == NULL)
-    return EINVAL;
+  if (name == NULL)
+    return MU_ERR_OUT_PTR_NULL;
 
-  if((ret = message_get_attachment_name(msg, NULL, 0, &sz)) != 0)
+  if((ret = mu_message_get_attachment_name(msg, NULL, 0, &sz)) != 0)
     return ret;
 
   *name = malloc(sz + 1);
 
-  if((ret = message_get_attachment_name(msg, *name, sz + 1, NULL)) != 0)
+  if((ret = mu_message_get_attachment_name(msg, *name, sz + 1, NULL)) != 0)
   {
     free(*name);
     *name = NULL;
@@ -295,10 +299,10 @@ int message_aget_attachment_name(message_t msg, char** name)
 }
 
 int
-message_get_attachment_name (message_t msg, char *buf, size_t bufsz, size_t *sz)
+mu_message_get_attachment_name (mu_message_t msg, char *buf, size_t bufsz, size_t *sz)
 {
   int ret = EINVAL;
-  header_t hdr;
+  mu_header_t hdr;
   char *value = NULL;
   char *name = NULL;
   size_t namesz = 0;
@@ -306,14 +310,14 @@ message_get_attachment_name (message_t msg, char *buf, size_t bufsz, size_t *sz)
   if(!msg)
     return ret;
 
-  if ((ret = message_get_header (msg, &hdr)) != 0)
+  if ((ret = mu_message_get_header (msg, &hdr)) != 0)
     return ret;
 
-  ret = header_aget_value (hdr, "Content-Disposition", &value);
+  ret = mu_header_aget_value (hdr, "Content-Disposition", &value);
 
   /* If the header wasn't there, we'll fall back to Content-Type, but
      other errors are fatal. */
-  if(ret != 0 && ret != ENOENT)
+  if(ret != 0 && ret != MU_ERR_NOENT)
     return ret;
 
   if(ret == 0 && value != NULL)
@@ -333,7 +337,7 @@ message_get_attachment_name (message_t msg, char *buf, size_t bufsz, size_t *sz)
       if(value)
 	free(value);
 
-      ret = header_aget_value (hdr, "Content-Type", &value);
+      ret = mu_header_aget_value (hdr, "Content-Type", &value);
       name = _header_get_param (value, "name", &namesz);
     }
 
@@ -350,20 +354,20 @@ message_get_attachment_name (message_t msg, char *buf, size_t bufsz, size_t *sz)
 	strncpy(buf, name, bufsz);
     }
   else
-    ret = ENOENT;
+    ret = MU_ERR_NOENT;
 
   return ret;
 }
 
 int
-message_save_attachment (message_t msg, const char *filename, void **data)
+mu_message_save_attachment (mu_message_t msg, const char *filename, void **data)
 {
-  stream_t istream;
+  mu_stream_t istream;
   struct _msg_info *info = NULL;
   int ret;
   size_t size;
   size_t nbytes;
-  header_t hdr;
+  mu_header_t hdr;
   char *content_encoding;
   const char *fname = NULL;
   char *partname = NULL;
@@ -374,11 +378,11 @@ message_save_attachment (message_t msg, const char *filename, void **data)
   if ((ret = _attachment_setup (&info, msg, &istream, data)) != 0)
     return ret;
 
-  if (ret == 0 && (ret = message_get_header (msg, &hdr)) == 0)
+  if (ret == 0 && (ret = mu_message_get_header (msg, &hdr)) == 0)
     {
       if (filename == NULL)
       {
-	ret = message_aget_attachment_name (msg, &partname);
+	ret = mu_message_aget_attachment_name (msg, &partname);
 	if(partname)
 	  fname = partname;
       }
@@ -386,24 +390,24 @@ message_save_attachment (message_t msg, const char *filename, void **data)
 	fname = filename;
       if (fname
 	  && (ret =
-	      file_stream_create (&info->fstream, fname,
+	      mu_file_stream_create (&info->fstream, fname,
 				  MU_STREAM_WRITE | MU_STREAM_CREAT)) == 0)
 	{
-	  if ((ret = stream_open (info->fstream)) == 0)
+	  if ((ret = mu_stream_open (info->fstream)) == 0)
 	    {
-	      header_get_value (hdr, "Content-Transfer-Encoding", NULL, 0,
+	      mu_header_get_value (hdr, "Content-Transfer-Encoding", NULL, 0,
 				&size);
 	      if (size)
 		{
 		  if ((content_encoding = alloca (size + 1)) == NULL)
 		    ret = ENOMEM;
-		  header_get_value (hdr, "Content-Transfer-Encoding",
+		  mu_header_get_value (hdr, "Content-Transfer-Encoding",
 				    content_encoding, size + 1, 0);
 		}
 	      else
 		content_encoding = (char *) "7bit";
 	      ret =
-		filter_create (&info->stream, istream, content_encoding,
+		mu_filter_create (&info->stream, istream, content_encoding,
 			       MU_FILTER_DECODE, MU_STREAM_READ);
 	    }
 	}
@@ -416,14 +420,14 @@ message_save_attachment (message_t msg, const char *filename, void **data)
       while ((ret == 0 && info->nbytes)
 	     ||
 	     ((ret =
-	       stream_read (info->stream, info->buf, BUF_SIZE, info->ioffset,
+	       mu_stream_read (info->stream, info->buf, BUF_SIZE, info->ioffset,
 			    &info->nbytes)) == 0 && info->nbytes))
 	{
 	  info->ioffset += info->nbytes;
 	  while (info->nbytes)
 	    {
 	      if ((ret =
-		   stream_write (info->fstream, info->buf, info->nbytes,
+		   mu_stream_write (info->fstream, info->buf, info->nbytes,
 				 info->ooffset, &nbytes)) != 0)
 		break;
 	      info->nbytes -= nbytes;
@@ -433,9 +437,9 @@ message_save_attachment (message_t msg, const char *filename, void **data)
     }
   if (ret != EAGAIN && info)
     {
-      stream_close (info->fstream);
-      stream_destroy (&info->stream, NULL);
-      stream_destroy (&info->fstream, NULL);
+      mu_stream_close (info->fstream);
+      mu_stream_destroy (&info->stream, NULL);
+      mu_stream_destroy (&info->fstream, NULL);
       _attachment_free (info, ret);
     }
 
@@ -447,33 +451,35 @@ message_save_attachment (message_t msg, const char *filename, void **data)
 }
 
 int
-message_encapsulate (message_t msg, message_t * newmsg, void **data)
+mu_message_encapsulate (mu_message_t msg, mu_message_t * newmsg, void **data)
 {
-  stream_t istream, ostream;
+  mu_stream_t istream, ostream;
   const char *header;
   struct _msg_info *info = NULL;
   int ret = 0;
   size_t nbytes;
-  body_t body;
+  mu_body_t body;
 
-  if (msg == NULL || newmsg == NULL)
+  if (msg == NULL)
     return EINVAL;
+  if (newmsg == NULL)
+    return MU_ERR_OUT_PTR_NULL;
 
   if ((ret = _attachment_setup (&info, msg, &ostream, data)) != 0)
     return ret;
 
-  if (info->msg == NULL && (ret = message_create (&(info->msg), NULL)) == 0)
+  if (info->msg == NULL && (ret = mu_message_create (&(info->msg), NULL)) == 0)
     {
       header =
 	"Content-Type: message/rfc822\nContent-Transfer-Encoding: 7bit\n\n";
       if ((ret =
-	   header_create (&(info->hdr), header, strlen (header), msg)) == 0)
-	ret = message_set_header (info->msg, info->hdr, NULL);
+	   mu_header_create (&(info->hdr), header, strlen (header), msg)) == 0)
+	ret = mu_message_set_header (info->msg, info->hdr, NULL);
     }
-  if (ret == 0 && (ret = message_get_stream (msg, &istream)) == 0)
+  if (ret == 0 && (ret = mu_message_get_stream (msg, &istream)) == 0)
     {
-      if ((ret = message_get_body (info->msg, &body)) == 0 &&
-	  (ret = body_get_stream (body, &ostream)) == 0)
+      if ((ret = mu_message_get_body (info->msg, &body)) == 0 &&
+	  (ret = mu_body_get_stream (body, &ostream)) == 0)
 	{
 	  if (info->nbytes)
 	    memmove (info->buf, info->buf + (BUF_SIZE - info->nbytes),
@@ -481,14 +487,14 @@ message_encapsulate (message_t msg, message_t * newmsg, void **data)
 	  while ((ret == 0 && info->nbytes)
 		 ||
 		 ((ret =
-		   stream_read (istream, info->buf, BUF_SIZE, info->ioffset,
+		   mu_stream_read (istream, info->buf, BUF_SIZE, info->ioffset,
 				&info->nbytes)) == 0 && info->nbytes))
 	    {
 	      info->ioffset += info->nbytes;
 	      while (info->nbytes)
 		{
 		  if ((ret =
-		       stream_write (ostream, info->buf, info->nbytes,
+		       mu_stream_write (ostream, info->buf, info->nbytes,
 				     info->ooffset, &nbytes)) != 0)
 		    break;
 		  info->nbytes -= nbytes;
@@ -505,27 +511,29 @@ message_encapsulate (message_t msg, message_t * newmsg, void **data)
 }
 
 int
-message_unencapsulate (message_t msg, message_t * newmsg, void **data)
+mu_message_unencapsulate (mu_message_t msg, mu_message_t * newmsg, void **data)
 {
   size_t size, nbytes;
   int ret = 0;
   char *content_type;
-  header_t hdr;
-  stream_t istream, ostream;
+  mu_header_t hdr;
+  mu_stream_t istream, ostream;
   struct _msg_info *info = NULL;
 
-  if (msg == NULL || newmsg == NULL)
+  if (msg == NULL)
     return EINVAL;
+  if (newmsg == NULL)
+    return MU_ERR_OUT_PTR_NULL;
 
   if ((data == NULL || *data == NULL)
-      && (ret = message_get_header (msg, &hdr)) == 0)
+      && (ret = mu_message_get_header (msg, &hdr)) == 0)
     {
-      header_get_value (hdr, "Content-Type", NULL, 0, &size);
+      mu_header_get_value (hdr, "Content-Type", NULL, 0, &size);
       if (size)
 	{
 	  if ((content_type = alloca (size + 1)) == NULL)
 	    return ENOMEM;
-	  header_get_value (hdr, "Content-Type", content_type, size + 1, 0);
+	  mu_header_get_value (hdr, "Content-Type", content_type, size + 1, 0);
 	  if (strncasecmp
 	      (content_type, "message/rfc822",
 	       strlen ("message/rfc822")) != 0)
@@ -537,24 +545,24 @@ message_unencapsulate (message_t msg, message_t * newmsg, void **data)
   if ((ret = _attachment_setup (&info, msg, &istream, data)) != 0)
     return ret;
   if (info->msg == NULL)
-    ret = message_create (&(info->msg), NULL);
+    ret = mu_message_create (&(info->msg), NULL);
   if (ret == 0)
     {
-      message_get_stream (info->msg, &ostream);
+      mu_message_get_stream (info->msg, &ostream);
       if (info->nbytes)
 	memmove (info->buf, info->buf + (BUF_SIZE - info->nbytes),
 		 info->nbytes);
       while ((ret == 0 && info->nbytes)
 	     ||
 	     ((ret =
-	       stream_read (istream, info->buf, BUF_SIZE, info->ioffset,
+	       mu_stream_read (istream, info->buf, BUF_SIZE, info->ioffset,
 			    &info->nbytes)) == 0 && info->nbytes))
 	{
 	  info->ioffset += info->nbytes;
 	  while (info->nbytes)
 	    {
 	      if ((ret =
-		   stream_write (ostream, info->buf, info->nbytes,
+		   mu_stream_write (ostream, info->buf, info->nbytes,
 				 info->ooffset, &nbytes)) != 0)
 		break;
 	      info->nbytes -= nbytes;
