@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2004, 2005 Free Software Foundation, Inc.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
@@ -11,9 +11,10 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Lesser General Public
-   License along with this library; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   You should have received a copy of the GNU Lesser General
+   Public License along with this library; if not, write to the
+   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301 USA */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -21,12 +22,14 @@
 
 #include <errno.h>
 #include <sys/types.h>
+#include <unistd.h>
 #include <string.h>
 #include <stdlib.h>
 #include <stdio.h>
 #include <termios.h>
 
 #include <mailutils/mutil.h>
+#include <mailutils/errno.h>
 #include <auth0.h>
 
 static void
@@ -46,11 +49,11 @@ echo_on(struct termios *stored_settings)
 }
 
 int
-ticket_create (ticket_t *pticket, void *owner)
+mu_ticket_create (mu_ticket_t *pticket, void *owner)
 {
-  ticket_t ticket;
+  mu_ticket_t ticket;
   if (pticket == NULL)
-    return EINVAL;
+    return MU_ERR_OUT_PTR_NULL;
   ticket = calloc (1, sizeof (*ticket));
   if (ticket == NULL)
     return ENOMEM;
@@ -60,11 +63,11 @@ ticket_create (ticket_t *pticket, void *owner)
 }
 
 void
-ticket_destroy (ticket_t *pticket, void *owner)
+mu_ticket_destroy (mu_ticket_t *pticket, void *owner)
 {
   if (pticket && *pticket)
     {
-      ticket_t ticket = *pticket;
+      mu_ticket_t ticket = *pticket;
       if (ticket->owner == owner)
 	{
 	  if (ticket->_destroy)
@@ -78,7 +81,7 @@ ticket_destroy (ticket_t *pticket, void *owner)
 }
 
 int
-ticket_set_destroy (ticket_t ticket, void (*_destroy) __P ((ticket_t)),
+mu_ticket_set_destroy (mu_ticket_t ticket, void (*_destroy) (mu_ticket_t),
 		    void *owner)
 {
   if (ticket == NULL)
@@ -90,14 +93,14 @@ ticket_set_destroy (ticket_t ticket, void (*_destroy) __P ((ticket_t)),
 }
 
 void *
-ticket_get_owner (ticket_t ticket)
+mu_ticket_get_owner (mu_ticket_t ticket)
 {
   return (ticket) ? ticket->owner : NULL;
 }
 
 int
-ticket_set_pop (ticket_t ticket,
-		int (*_pop) __P ((ticket_t, url_t, const char *, char **)),
+mu_ticket_set_pop (mu_ticket_t ticket,
+		int (*_pop) (mu_ticket_t, mu_url_t, const char *, char **),
 		void *owner)
 {
   if (ticket == NULL)
@@ -109,13 +112,17 @@ ticket_set_pop (ticket_t ticket,
 }
 
 int
-ticket_pop (ticket_t ticket, url_t url, const char *challenge, char **parg)
+mu_ticket_pop (mu_ticket_t ticket, mu_url_t url, const char *challenge, char **parg)
 {
-  if (ticket == NULL || parg == NULL)
+  int rc = -1;
+  
+  if (ticket == NULL)
     return EINVAL;
+  if (parg == NULL)
+    return MU_ERR_OUT_PTR_NULL;
   if (ticket->_pop)
-    return ticket->_pop (ticket, url, challenge, parg);
-  else
+    rc = ticket->_pop (ticket, url, challenge, parg);
+  if (rc != 0 && isatty (fileno (stdin)))
     {
       char arg[256];
       struct termios stored_settings;
@@ -138,21 +145,24 @@ ticket_pop (ticket_t ticket, url_t url, const char *challenge, char **parg)
 	}
       arg [strlen (arg) - 1] = '\0'; /* nuke the trailing line.  */
       *parg = strdup (arg);
+      rc = 0;
     }
-  return 0;
+  return rc;
 }
 
 int
-ticket_get_data (ticket_t ticket, void **data)
+mu_ticket_get_data (mu_ticket_t ticket, void **data)
 {
-  if (ticket == NULL || data == NULL)
+  if (ticket == NULL)
     return EINVAL;
+  if (data == NULL)
+    return MU_ERR_OUT_PTR_NULL;
   *data = ticket->data;
   return 0;
 }
 
 int
-ticket_set_data (ticket_t ticket, void *data, void *owner)
+mu_ticket_set_data (mu_ticket_t ticket, void *data, void *owner)
 {
   if (ticket == NULL)
     return EINVAL;
