@@ -1,5 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001, 2002, 2003 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2002, 2003, 2005,
+   2006  Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -21,10 +22,8 @@
 #include <mh.h>
 
 const char *program_version = "fmtcheck (" PACKAGE_STRING ")";
-/* TRANSLATORS: Please, preserve the vertical tabulation (^K character)
-   in this message */
-static char doc[] = N_("GNU MH fmtcheck\v\
-Use -help to obtain the list of traditional MH options.");
+static char doc[] = N_("GNU MH fmtcheck")"\v"
+N_("Use -help to obtain the list of traditional MH options.");
 static char args_doc[] = "";
 
 /* GNU options */
@@ -53,14 +52,14 @@ struct mh_option mh_option[] = {
 char *format_str;
 static mh_format_t format;
 
-typedef int (*action_fp) __P((void));
+typedef int (*action_fp) (void);
 
 static int
 action_dump ()
 {
   if (!format_str)
     {
-      mh_error (_("Format string not specified"));
+      mu_error (_("Format string not specified"));
       return 1;
     }
   mh_format_dump (&format);
@@ -112,7 +111,7 @@ main (int argc, char **argv)
 
   if (format_str && mh_format_parse (format_str, &format))
     {
-      mh_error (_("Bad format string"));
+      mu_error (_("Bad format string"));
       exit (1);
     }
   return (*action) ();
