@@ -1,6 +1,6 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
    Copyright (C) 1999, 2000, 2001, 2002, 2003, 
-   2005 Free Software Foundation, Inc.
+   2005, 2006 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -35,10 +35,8 @@
 #include <obstack.h>
 
 const char *program_version = "folder (" PACKAGE_STRING ")";
-/* TRANSLATORS: Please, preserve the vertical tabulation (^K character)
-   in this message */
-static char doc[] = N_("GNU MH folder\v\
-Use -help to obtain the list of traditional MH options.");
+static char doc[] = N_("GNU MH folder")"\v"
+N_("Use -help to obtain the list of traditional MH options.");
 static char args_doc[] = N_("[action] [msg]");
 
 static struct argp_option options[] = {
@@ -120,9 +118,10 @@ int create_flag = -1; /* Create non-existent folders (--create).
 		          0: Do not create
 		          1: Always create without prompting */
 int fast_mode = 0; /* Fast operation mode. (--fast) */
-int print_header = 0; /* Display the header line (--header) */
-int recurse = 0;   /* Recurse sub-folders */
-int print_total;   /* Display total stats */
+  /* The following two vars are three-state, -1 meaning the default for
+     current mode */
+int print_header = -1; /* Display the header line (--header) */
+int print_total = -1;  /* Display total stats */
 int verbose = 0;   /* Verbosely list actions taken */
 size_t pack_start; /* Number to be assigned to the first message in packed
 		      folder. 0 means do not change first message number. */
@@ -131,6 +130,10 @@ char *push_folder; /* Folder name to push on stack */
 
 char *mh_seq_name; /* Name of the mh sequence file (defaults to
 		      .mh_sequences) */
+int has_folder;    /* Folder has been explicitely given */
+size_t max_depth = 1;  /* Maximum recursion depth (0 means infinity) */ 
+
+#define OPTION_IS_SET(opt) ((opt) == -1 ? show_all : opt)
 
 static int
 opt_handler (int key, char *arg, void *unused, struct argp_state *state)
@@ -174,7 +177,7 @@ opt_handler (int key, char *arg, void *unused, struct argp_state *state)
       break;
       
     case ARG_ALL:
-      show_all++;
+      show_all = 1;
       break;
 
     case ARG_CREATE:
@@ -201,11 +204,11 @@ opt_handler (int key, char *arg, void *unused, struct argp_state *state)
       break;
       
     case ARG_RECURSIVE:
-      recurse = is_true (arg);
+      max_depth = is_true (arg) ? 0 : 1;
       break;
 
     case ARG_NORECURSIVE:
-      recurse = 0;
+      max_depth = 0;
       break;
       
     case ARG_TOTAL:
@@ -217,6 +220,7 @@ opt_handler (int key, char *arg, void *unused, struct argp_state *state)
       break;
       
     case ARG_FOLDER:
+      has_folder = 1;
       push_folder = mh_current_folder ();
       current_folder = arg;
       break;
@@ -295,7 +299,7 @@ read_seq_file (struct folder_info *info, const char *prefix, const char *name)
 }
 
 static void
-_scan (const char *name, int depth)
+_scan (const char *name, size_t depth)
 {
   DIR *dir;
   struct dirent *entry;
@@ -304,20 +308,6 @@ _scan (const char *name, int depth)
   struct stat st;
   size_t uid;
 
-  if (!recurse)
-    {
-      if (fast_mode && depth > 0)
-	{
-	  memset (&info, 0, sizeof (info));
-	  info.name = strdup (name);
-	  install_folder_info (name, &info);
-	  return;
-	}
-      
-      if (depth > 1)
-	return;
-    }
-  
   dir = opendir (name);
 
   if (!dir && errno == ENOENT)
@@ -332,18 +322,33 @@ _scan (const char *name, int depth)
 	  dir = opendir (name);
 	}
       else
-	{
-	  push_folder = 0;
-	  return;
-	}
+	exit (1);
     }
 
   if (!dir)
     {
-      mh_error (_("Cannot scan folder %s: %s"), name, strerror (errno));
+      mu_error (_("Cannot scan folder %s: %s"), name, strerror (errno));
       return;
     }
 
+  if (max_depth == 1)
+    {
+      if (fast_mode && depth > 0)
+	{
+	  memset (&info, 0, sizeof (info));
+	  info.name = strdup (name);
+	  install_folder_info (name, &info);
+	  closedir (dir);
+	  return;
+	}
+    }
+  
+  if (max_depth && depth > max_depth)
+    {
+      closedir (dir);
+      return;
+    }
+  
   memset (&info, 0, sizeof (info));
   info.name = strdup (name);
   while ((entry = readdir (dir)))
@@ -357,7 +362,7 @@ _scan (const char *name, int depth)
 	{
 	  asprintf (&p, "%s/%s", name, entry->d_name);
 	  if (stat (p, &st) < 0)
-	    mh_error (_("Cannot stat %s: %s"), p, strerror (errno));
+	    mu_error (_("Cannot stat %s: %s"), p, strerror (errno));
 	  else if (S_ISDIR (st.st_mode))
 	    {
 	      info.others++;
@@ -480,12 +485,12 @@ action_print ()
     print_fast ();
   else
     {
-      if (print_header)                                   
+      if (OPTION_IS_SET (print_header))
 	printf (_("Folder                  # of messages     (  range  )  cur msg   (other files)\n"));
 		
       print_all ();
 
-      if (print_total)
+      if (OPTION_IS_SET (print_total))
 	{
 	  printf ("\n%24.24s=", _("TOTAL"));
 	  printf (ngettext ("%4lu message  ", "%4lu messages ",
@@ -617,7 +622,7 @@ pack_rename (struct pack_tab *tab, int reverse)
   if (!dry_run)
     {
       if ((rc = rename (from, to)))
-	mh_error (_("cannot rename `%s' to `%s': %s"),
+	mu_error (_("cannot rename `%s' to `%s': %s"),
 		  from, to, mu_strerror (errno));
     }
   else
@@ -654,11 +659,11 @@ roll_back (const char *folder_name, struct pack_tab *pack_tab, size_t i)
     return;
   
   start = i - 1;
-  mh_error (_("Rolling back changes..."));
+  mu_error (_("Rolling back changes..."));
   while (--i >= 0)
     if (pack_rename (pack_tab + i, 1))
       {
-	mh_error (_("CRITICAL ERROR: Folder `%s' left in an inconsistent state, because an error\n"
+	mu_error (_("CRITICAL ERROR: Folder `%s' left in an inconsistent state, because an error\n"
 		    "occurred while trying to roll back the changes.\n"
 		    "Message range %s-%s has been renamed to %s-%s."),
 		  folder_name,
@@ -666,10 +671,10 @@ roll_back (const char *folder_name, struct pack_tab *pack_tab, size_t i)
                   mu_umaxtostr (1, pack_tab[start].orig),
 		  mu_umaxtostr (2, pack_tab[0].new),
                   mu_umaxtostr (3, pack_tab[start].new));
-	mh_error (_("You will have to fix it manually."));
+	mu_error (_("You will have to fix it manually."));
 	exit (1);
       }
-  mh_error (_("Folder `%s' restored successfully"), folder_name);
+  mu_error (_("Folder `%s' restored successfully"), folder_name);
 }
 
 struct fixup_data
@@ -774,7 +779,7 @@ action_pack ()
   /* Allocate pack table */
   if (mu_mailbox_messages_count (mbox, &count))
     {
-      mh_error (_("Cannot read input mailbox: %s"), mu_strerror (errno));
+      mu_error (_("Cannot read input mailbox: %s"), mu_strerror (errno));
       return 1;
     }
   pack_tab = xcalloc (count, sizeof pack_tab[0]); /* Never freed. No use to
@@ -790,7 +795,7 @@ action_pack ()
       status = mu_mailbox_get_message (mbox, i + 1, &msg);
       if (status)
 	{
-	  mh_error (_("%d: cannot get message: %s"), i, mu_strerror (status));
+	  mu_error (_("%d: cannot get message: %s"), i, mu_strerror (status));
 	  return 1;
 	}
       mh_message_number (msg, &pack_tab[i].orig);
@@ -822,7 +827,7 @@ action_pack ()
   status = chdir (folder_dir);
   if (status)
     {
-      mh_error (_("cannot change to directory `%s': %s"),
+      mu_error (_("cannot change to directory `%s': %s"),
 		folder_dir, mu_strerror (status));
       return 1;
     }
@@ -872,8 +877,19 @@ main (int argc, char **argv)
   /* If  folder  is invoked by a name ending with "s" (e.g.,  folders),
      `-all'  is  assumed */
   if (program_invocation_short_name[strlen (program_invocation_short_name) - 1] == 's')
-    show_all++;
-
+    show_all = 1;
+  
+  if (has_folder)
+    {
+      /* If a +folder is given along with the -all switch, folder will, in
+	 addition to setting the current folder, list the top-level
+	 subfolders for the current folder (with -norecurse) or list all
+	 sub-folders under the current folder recursively (with -recurse). */
+      if (show_all && max_depth)
+	max_depth = 2;
+      show_all = 0;
+    }
+    
   if (argc - index == 1)
     {
       mu_mailbox_t mbox = mh_open_folder (current_folder, 0);
@@ -885,12 +901,9 @@ main (int argc, char **argv)
     }
   else if (argc - index > 1)
     {
-      mh_error (_("Too many arguments"));
+      mu_error (_("Too many arguments"));
       exit (1);
     }
   
-  if (show_all)
-    print_header = print_total = 1;
-  
   return (*action) ();
 }
