@@ -21,10 +21,8 @@
 #include <mh.h>
 
 const char *program_version = "forw (" PACKAGE_STRING ")";
-/* TRANSLATORS: Please, preserve the vertical tabulation (^K character)
-   in this message */
-static char doc[] = N_("GNU MH forw\v\
-Options marked with `*' are not yet implemented.\n\
+static char doc[] = N_("GNU MH forw")"\v"
+N_("Options marked with `*' are not yet implemented.\n\
 Use -help to obtain the list of traditional MH options.");
 static char args_doc[] = "[msgs]";
 
