@@ -1,7 +1,7 @@
-/* A Bison parser, made by GNU Bison 2.1.  */
+/* A Bison parser, made by GNU Bison 1.875.  */
 
 /* Skeleton parser for Yacc-like parsing with Bison,
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,8 +15,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.  */
+   Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.  */
 
 /* As a special exception, when this file is copied by Bison into a
    Bison output file, you may use that output file without restriction.
@@ -36,9 +36,6 @@
 /* Identify Bison output.  */
 #define YYBISON 1
 
-/* Bison version.  */
-#define YYBISON_VERSION "2.1"
-
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
 
@@ -59,7 +56,6 @@
      STRING = 258
    };
 #endif
-/* Tokens.  */
 #define STRING 258
 
 
@@ -69,7 +65,7 @@
 #line 1 "mh_alias.y"
 
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2003, 2004, 2005 Free Software Foundation, Inc.
+   Copyright (C) 2003, 2004, 2005, 2006 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -178,11 +174,6 @@ int ali_yylex (void);
 # define YYERROR_VERBOSE 0
 #endif
 
-/* Enabling the token table.  */
-#ifndef YYTOKEN_TABLE
-# define YYTOKEN_TABLE 0
-#endif
-
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
 #line 99 "mh_alias.y"
 typedef union YYSTYPE {
@@ -190,8 +181,8 @@ typedef union YYSTYPE {
   mu_list_t list;
   struct mh_alias *alias;
 } YYSTYPE;
-/* Line 196 of yacc.c.  */
-#line 195 "mh_alias_gram.c"
+/* Line 191 of yacc.c.  */
+#line 185 "mh_alias_gram.c"
 # define ali_yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
@@ -202,48 +193,22 @@ typedef union YYSTYPE {
 /* Copy the second part of user declarations.  */
 
 
-/* Line 219 of yacc.c.  */
-#line 207 "mh_alias_gram.c"
-
-#if ! defined (YYSIZE_T) && defined (__SIZE_TYPE__)
-# define YYSIZE_T __SIZE_TYPE__
-#endif
-#if ! defined (YYSIZE_T) && defined (size_t)
-# define YYSIZE_T size_t
-#endif
-#if ! defined (YYSIZE_T) && (defined (__STDC__) || defined (__cplusplus))
-# include <stddef.h> /* INFRINGES ON USER NAME SPACE */
-# define YYSIZE_T size_t
-#endif
-#if ! defined (YYSIZE_T)
-# define YYSIZE_T unsigned int
-#endif
-
-#ifndef YY_
-# if YYENABLE_NLS
-#  if ENABLE_NLS
-#   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
-#   define YY_(msgid) dgettext ("bison-runtime", msgid)
-#  endif
-# endif
-# ifndef YY_
-#  define YY_(msgid) msgid
-# endif
-#endif
+/* Line 214 of yacc.c.  */
+#line 197 "mh_alias_gram.c"
 
 #if ! defined (ali_yyoverflow) || YYERROR_VERBOSE
 
 /* The parser invokes alloca or malloc; define the necessary symbols.  */
 
-# ifdef YYSTACK_USE_ALLOCA
-#  if YYSTACK_USE_ALLOCA
-#   ifdef __GNUC__
-#    define YYSTACK_ALLOC __builtin_alloca
-#   else
+# if YYSTACK_USE_ALLOCA
+#  define YYSTACK_ALLOC alloca
+# else
+#  ifndef YYSTACK_USE_ALLOCA
+#   if defined (alloca) || defined (_ALLOCA_H)
 #    define YYSTACK_ALLOC alloca
-#    if defined (__STDC__) || defined (__cplusplus)
-#     include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
-#     define YYINCLUDED_STDLIB_H
+#   else
+#    ifdef __GNUC__
+#     define YYSTACK_ALLOC __builtin_alloca
 #    endif
 #   endif
 #  endif
@@ -252,51 +217,25 @@ typedef union YYSTYPE {
 # ifdef YYSTACK_ALLOC
    /* Pacify GCC's `empty if-body' warning. */
 #  define YYSTACK_FREE(Ptr) do { /* empty */; } while (0)
-#  ifndef YYSTACK_ALLOC_MAXIMUM
-    /* The OS might guarantee only one guard page at the bottom of the stack,
-       and a page size can be as small as 4096 bytes.  So we cannot safely
-       invoke alloca (N) if N exceeds 4096.  Use a slightly smaller number
-       to allow for a few compiler-allocated temporary stack slots.  */
-#   define YYSTACK_ALLOC_MAXIMUM 4032 /* reasonable circa 2005 */
-#  endif
 # else
-#  define YYSTACK_ALLOC YYMALLOC
-#  define YYSTACK_FREE YYFREE
-#  ifndef YYSTACK_ALLOC_MAXIMUM
-#   define YYSTACK_ALLOC_MAXIMUM ((YYSIZE_T) -1)
-#  endif
-#  ifdef __cplusplus
-extern "C" {
-#  endif
-#  ifndef YYMALLOC
-#   define YYMALLOC malloc
-#   if (! defined (malloc) && ! defined (YYINCLUDED_STDLIB_H) \
-	&& (defined (__STDC__) || defined (__cplusplus)))
-void *malloc (YYSIZE_T); /* INFRINGES ON USER NAME SPACE */
-#   endif
-#  endif
-#  ifndef YYFREE
-#   define YYFREE free
-#   if (! defined (free) && ! defined (YYINCLUDED_STDLIB_H) \
-	&& (defined (__STDC__) || defined (__cplusplus)))
-void free (void *); /* INFRINGES ON USER NAME SPACE */
-#   endif
-#  endif
-#  ifdef __cplusplus
-}
+#  if defined (__STDC__) || defined (__cplusplus)
+#   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
+#   define YYSIZE_T size_t
 #  endif
+#  define YYSTACK_ALLOC malloc
+#  define YYSTACK_FREE free
 # endif
 #endif /* ! defined (ali_yyoverflow) || YYERROR_VERBOSE */
 
 
 #if (! defined (ali_yyoverflow) \
      && (! defined (__cplusplus) \
-	 || (defined (YYSTYPE_IS_TRIVIAL) && YYSTYPE_IS_TRIVIAL)))
+	 || (YYSTYPE_IS_TRIVIAL)))
 
 /* A type that is properly aligned for any stack member.  */
 union ali_yyalloc
 {
-  short int ali_yyss;
+  short ali_yyss;
   YYSTYPE ali_yyvs;
   };
 
@@ -306,20 +245,20 @@ union ali_yyalloc
 /* The size of an array large to enough to hold all stacks, each with
    N elements.  */
 # define YYSTACK_BYTES(N) \
-     ((N) * (sizeof (short int) + sizeof (YYSTYPE))			\
+     ((N) * (sizeof (short) + sizeof (YYSTYPE))				\
       + YYSTACK_GAP_MAXIMUM)
 
 /* Copy COUNT objects from FROM to TO.  The source and destination do
    not overlap.  */
 # ifndef YYCOPY
-#  if defined (__GNUC__) && 1 < __GNUC__
+#  if 1 < __GNUC__
 #   define YYCOPY(To, From, Count) \
       __builtin_memcpy (To, From, (Count) * sizeof (*(From)))
 #  else
 #   define YYCOPY(To, From, Count)		\
       do					\
 	{					\
-	  YYSIZE_T ali_yyi;				\
+	  register YYSIZE_T ali_yyi;		\
 	  for (ali_yyi = 0; ali_yyi < (Count); ali_yyi++)	\
 	    (To)[ali_yyi] = (From)[ali_yyi];		\
 	}					\
@@ -348,7 +287,7 @@ union ali_yyalloc
 #if defined (__STDC__) || defined (__cplusplus)
    typedef signed char ali_yysigned_char;
 #else
-   typedef short int ali_yysigned_char;
+   typedef short ali_yysigned_char;
 #endif
 
 /* YYFINAL -- State number of the termination state. */
@@ -369,7 +308,7 @@ union ali_yyalloc
 #define YYUNDEFTOK  2
 #define YYMAXUTOK   258
 
-#define YYTRANSLATE(YYX)						\
+#define YYTRANSLATE(YYX) 						\
   ((unsigned int) (YYX) <= YYMAXUTOK ? ali_yytranslate[YYX] : YYUNDEFTOK)
 
 /* YYTRANSLATE[YYLEX] -- Bison symbol number corresponding to YYLEX.  */
@@ -434,13 +373,13 @@ static const unsigned char ali_yyrline[] =
 };
 #endif
 
-#if YYDEBUG || YYERROR_VERBOSE || YYTOKEN_TABLE
-/* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
+#if YYDEBUG || YYERROR_VERBOSE
+/* YYTNME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
    First, the terminals, then, starting at YYNTOKENS, nonterminals. */
 static const char *const ali_yytname[] =
 {
-  "$end", "error", "$undefined", "STRING", "'\\n'", "':'", "';'", "'='",
-  "'+'", "'*'", "','", "$accept", "input", "alias_list", "nl", "alias",
+  "$end", "error", "$undefined", "STRING", "'\\n'", "':'", "';'", "'='", 
+  "'+'", "'*'", "','", "$accept", "input", "alias_list", "nl", "alias", 
   "@1", "@2", "address_group", "address_list", "address", "string_list", 0
 };
 #endif
@@ -448,7 +387,7 @@ static const char *const ali_yytname[] =
 # ifdef YYPRINT
 /* YYTOKNUM[YYLEX-NUM] -- Internal token number corresponding to
    token YYLEX-NUM.  */
-static const unsigned short int ali_yytoknum[] =
+static const unsigned short ali_yytoknum[] =
 {
        0,   256,   257,   258,    10,    58,    59,    61,    43,    42,
       44
@@ -536,6 +475,22 @@ static const unsigned char ali_yystos[] =
       20
 };
 
+#if ! defined (YYSIZE_T) && defined (__SIZE_TYPE__)
+# define YYSIZE_T __SIZE_TYPE__
+#endif
+#if ! defined (YYSIZE_T) && defined (size_t)
+# define YYSIZE_T size_t
+#endif
+#if ! defined (YYSIZE_T)
+# if defined (__STDC__) || defined (__cplusplus)
+#  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
+#  define YYSIZE_T size_t
+# endif
+#endif
+#if ! defined (YYSIZE_T)
+# define YYSIZE_T unsigned int
+#endif
+
 #define ali_yyerrok		(ali_yyerrstatus = 0)
 #define ali_yyclearin	(ali_yychar = YYEMPTY)
 #define YYEMPTY		(-2)
@@ -543,8 +498,7 @@ static const unsigned char ali_yystos[] =
 
 #define YYACCEPT	goto ali_yyacceptlab
 #define YYABORT		goto ali_yyabortlab
-#define YYERROR		goto ali_yyerrorlab
-
+#define YYERROR		goto ali_yyerrlab1
 
 /* Like YYERROR except do call ali_yyerror.  This remains here temporarily
    to ease the transition to the new meaning of YYERROR, for GCC.
@@ -565,59 +519,26 @@ do								\
       goto ali_yybackup;						\
     }								\
   else								\
-    {								\
-      ali_yyerror (YY_("syntax error: cannot back up")); \
+    { 								\
+      ali_yyerror ("syntax error: cannot back up");\
       YYERROR;							\
     }								\
 while (0)
 
-
 #define YYTERROR	1
 #define YYERRCODE	256
 
+/* YYLLOC_DEFAULT -- Compute the default location (before the actions
+   are run).  */
 
-/* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
-   If N is 0, then set CURRENT to the empty location which ends
-   the previous symbol: RHS[0] (always defined).  */
-
-#define YYRHSLOC(Rhs, K) ((Rhs)[K])
 #ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)				\
-    do									\
-      if (N)								\
-	{								\
-	  (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;	\
-	  (Current).first_column = YYRHSLOC (Rhs, 1).first_column;	\
-	  (Current).last_line    = YYRHSLOC (Rhs, N).last_line;		\
-	  (Current).last_column  = YYRHSLOC (Rhs, N).last_column;	\
-	}								\
-      else								\
-	{								\
-	  (Current).first_line   = (Current).last_line   =		\
-	    YYRHSLOC (Rhs, 0).last_line;				\
-	  (Current).first_column = (Current).last_column =		\
-	    YYRHSLOC (Rhs, 0).last_column;				\
-	}								\
-    while (0)
+# define YYLLOC_DEFAULT(Current, Rhs, N)         \
+  Current.first_line   = Rhs[1].first_line;      \
+  Current.first_column = Rhs[1].first_column;    \
+  Current.last_line    = Rhs[N].last_line;       \
+  Current.last_column  = Rhs[N].last_column;
 #endif
 
-
-/* YY_LOCATION_PRINT -- Print the location on the stream.
-   This macro was not mandated originally: define only if we know
-   we won't break user code: when these are the locations we know.  */
-
-#ifndef YY_LOCATION_PRINT
-# if YYLTYPE_IS_TRIVIAL
-#  define YY_LOCATION_PRINT(File, Loc)			\
-     fprintf (File, "%d.%d-%d.%d",			\
-              (Loc).first_line, (Loc).first_column,	\
-              (Loc).last_line,  (Loc).last_column)
-# else
-#  define YY_LOCATION_PRINT(File, Loc) ((void) 0)
-# endif
-#endif
-
-
 /* YYLEX -- calling `ali_yylex' with the right arguments.  */
 
 #ifdef YYLEX_PARAM
@@ -640,30 +561,36 @@ do {						\
     YYFPRINTF Args;				\
 } while (0)
 
-# define YY_SYMBOL_PRINT(Title, Type, Value, Location)		\
+# define YYDSYMPRINT(Args)			\
+do {						\
+  if (ali_yydebug)					\
+    ali_yysymprint Args;				\
+} while (0)
+
+# define YYDSYMPRINTF(Title, Token, Value, Location)		\
 do {								\
   if (ali_yydebug)							\
     {								\
       YYFPRINTF (stderr, "%s ", Title);				\
-      ali_yysymprint (stderr,					\
-                  Type, Value);	\
+      ali_yysymprint (stderr, 					\
+                  Token, Value);	\
       YYFPRINTF (stderr, "\n");					\
     }								\
 } while (0)
 
 /*------------------------------------------------------------------.
 | ali_yy_stack_print -- Print the state stack from its BOTTOM up to its |
-| TOP (included).                                                   |
+| TOP (cinluded).                                                   |
 `------------------------------------------------------------------*/
 
 #if defined (__STDC__) || defined (__cplusplus)
 static void
-ali_yy_stack_print (short int *bottom, short int *top)
+ali_yy_stack_print (short *bottom, short *top)
 #else
 static void
 ali_yy_stack_print (bottom, top)
-    short int *bottom;
-    short int *top;
+    short *bottom;
+    short *top;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
@@ -693,13 +620,13 @@ ali_yy_reduce_print (ali_yyrule)
 #endif
 {
   int ali_yyi;
-  unsigned long int ali_yylno = ali_yyrline[ali_yyrule];
-  YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu), ",
-             ali_yyrule - 1, ali_yylno);
+  unsigned int ali_yylineno = ali_yyrline[ali_yyrule];
+  YYFPRINTF (stderr, "Reducing stack by rule %d (line %u), ",
+             ali_yyrule - 1, ali_yylineno);
   /* Print the symbols being reduced, and their result.  */
   for (ali_yyi = ali_yyprhs[ali_yyrule]; 0 <= ali_yyrhs[ali_yyi]; ali_yyi++)
-    YYFPRINTF (stderr, "%s ", ali_yytname[ali_yyrhs[ali_yyi]]);
-  YYFPRINTF (stderr, "-> %s\n", ali_yytname[ali_yyr1[ali_yyrule]]);
+    YYFPRINTF (stderr, "%s ", ali_yytname [ali_yyrhs[ali_yyi]]);
+  YYFPRINTF (stderr, "-> %s\n", ali_yytname [ali_yyr1[ali_yyrule]]);
 }
 
 # define YY_REDUCE_PRINT(Rule)		\
@@ -713,7 +640,8 @@ do {					\
 int ali_yydebug;
 #else /* !YYDEBUG */
 # define YYDPRINTF(Args)
-# define YY_SYMBOL_PRINT(Title, Type, Value, Location)
+# define YYDSYMPRINT(Args)
+# define YYDSYMPRINTF(Title, Token, Value, Location)
 # define YY_STACK_PRINT(Bottom, Top)
 # define YY_REDUCE_PRINT(Rule)
 #endif /* !YYDEBUG */
@@ -728,9 +656,13 @@ int ali_yydebug;
    if the built-in stack extension method is used).
 
    Do not make this value too large; the results are undefined if
-   YYSTACK_ALLOC_MAXIMUM < YYSTACK_BYTES (YYMAXDEPTH)
+   SIZE_MAX < YYSTACK_BYTES (YYMAXDEPTH)
    evaluated with infinite-precision integer arithmetic.  */
 
+#if YYMAXDEPTH == 0
+# undef YYMAXDEPTH
+#endif
+
 #ifndef YYMAXDEPTH
 # define YYMAXDEPTH 10000
 #endif
@@ -752,7 +684,7 @@ ali_yystrlen (ali_yystr)
      const char *ali_yystr;
 #   endif
 {
-  const char *ali_yys = ali_yystr;
+  register const char *ali_yys = ali_yystr;
 
   while (*ali_yys++ != '\0')
     continue;
@@ -777,8 +709,8 @@ ali_yystpcpy (ali_yydest, ali_yysrc)
      const char *ali_yysrc;
 #   endif
 {
-  char *ali_yyd = ali_yydest;
-  const char *ali_yys = ali_yysrc;
+  register char *ali_yyd = ali_yydest;
+  register const char *ali_yys = ali_yysrc;
 
   while ((*ali_yyd++ = *ali_yys++) != '\0')
     continue;
@@ -788,55 +720,7 @@ ali_yystpcpy (ali_yydest, ali_yysrc)
 #  endif
 # endif
 
-# ifndef ali_yytnamerr
-/* Copy to YYRES the contents of YYSTR after stripping away unnecessary
-   quotes and backslashes, so that it's suitable for ali_yyerror.  The
-   heuristic is that double-quoting is unnecessary unless the string
-   contains an apostrophe, a comma, or backslash (other than
-   backslash-backslash).  YYSTR is taken from ali_yytname.  If YYRES is
-   null, do not copy; instead, return the length of what the result
-   would have been.  */
-static YYSIZE_T
-ali_yytnamerr (char *ali_yyres, const char *ali_yystr)
-{
-  if (*ali_yystr == '"')
-    {
-      size_t ali_yyn = 0;
-      char const *ali_yyp = ali_yystr;
-
-      for (;;)
-	switch (*++ali_yyp)
-	  {
-	  case '\'':
-	  case ',':
-	    goto do_not_strip_quotes;
-
-	  case '\\':
-	    if (*++ali_yyp != '\\')
-	      goto do_not_strip_quotes;
-	    /* Fall through.  */
-	  default:
-	    if (ali_yyres)
-	      ali_yyres[ali_yyn] = *ali_yyp;
-	    ali_yyn++;
-	    break;
-
-	  case '"':
-	    if (ali_yyres)
-	      ali_yyres[ali_yyn] = '\0';
-	    return ali_yyn;
-	  }
-    do_not_strip_quotes: ;
-    }
-
-  if (! ali_yyres)
-    return ali_yystrlen (ali_yystr);
-
-  return ali_yystpcpy (ali_yyres, ali_yystr) - ali_yyres;
-}
-# endif
-
-#endif /* YYERROR_VERBOSE */
+#endif /* !YYERROR_VERBOSE */
 
 
 
@@ -860,15 +744,15 @@ ali_yysymprint (ali_yyoutput, ali_yytype, ali_yyvaluep)
   (void) ali_yyvaluep;
 
   if (ali_yytype < YYNTOKENS)
-    YYFPRINTF (ali_yyoutput, "token %s (", ali_yytname[ali_yytype]);
+    {
+      YYFPRINTF (ali_yyoutput, "token %s (", ali_yytname[ali_yytype]);
+# ifdef YYPRINT
+      YYPRINT (ali_yyoutput, ali_yytoknum[ali_yytype], *ali_yyvaluep);
+# endif
+    }
   else
     YYFPRINTF (ali_yyoutput, "nterm %s (", ali_yytname[ali_yytype]);
 
-
-# ifdef YYPRINT
-  if (ali_yytype < YYNTOKENS)
-    YYPRINT (ali_yyoutput, ali_yytoknum[ali_yytype], *ali_yyvaluep);
-# endif
   switch (ali_yytype)
     {
       default:
@@ -884,11 +768,10 @@ ali_yysymprint (ali_yyoutput, ali_yytype, ali_yyvaluep)
 
 #if defined (__STDC__) || defined (__cplusplus)
 static void
-ali_yydestruct (const char *ali_yymsg, int ali_yytype, YYSTYPE *ali_yyvaluep)
+ali_yydestruct (int ali_yytype, YYSTYPE *ali_yyvaluep)
 #else
 static void
-ali_yydestruct (ali_yymsg, ali_yytype, ali_yyvaluep)
-    const char *ali_yymsg;
+ali_yydestruct (ali_yytype, ali_yyvaluep)
     int ali_yytype;
     YYSTYPE *ali_yyvaluep;
 #endif
@@ -896,10 +779,6 @@ ali_yydestruct (ali_yymsg, ali_yytype, ali_yyvaluep)
   /* Pacify ``unused variable'' warnings.  */
   (void) ali_yyvaluep;
 
-  if (!ali_yymsg)
-    ali_yymsg = "Deleting";
-  YY_SYMBOL_PRINT (ali_yymsg, ali_yytype, ali_yyvaluep, ali_yylocationp);
-
   switch (ali_yytype)
     {
 
@@ -927,10 +806,10 @@ int ali_yyparse ();
 
 
 
-/* The look-ahead symbol.  */
+/* The lookahead symbol.  */
 int ali_yychar;
 
-/* The semantic value of the look-ahead symbol.  */
+/* The semantic value of the lookahead symbol.  */
 YYSTYPE ali_yylval;
 
 /* Number of syntax errors so far.  */
@@ -956,17 +835,17 @@ ali_yyparse (void)
 #else
 int
 ali_yyparse ()
-    ;
+
 #endif
 #endif
 {
   
-  int ali_yystate;
-  int ali_yyn;
+  register int ali_yystate;
+  register int ali_yyn;
   int ali_yyresult;
   /* Number of tokens to shift before error messages enabled.  */
   int ali_yyerrstatus;
-  /* Look-ahead token as an internal (translated) token number.  */
+  /* Lookahead token as an internal (translated) token number.  */
   int ali_yytoken = 0;
 
   /* Three stacks and their tools:
@@ -978,14 +857,14 @@ ali_yyparse ()
      to reallocate them elsewhere.  */
 
   /* The state stack.  */
-  short int ali_yyssa[YYINITDEPTH];
-  short int *ali_yyss = ali_yyssa;
-  short int *ali_yyssp;
+  short	ali_yyssa[YYINITDEPTH];
+  short *ali_yyss = ali_yyssa;
+  register short *ali_yyssp;
 
   /* The semantic value stack.  */
   YYSTYPE ali_yyvsa[YYINITDEPTH];
   YYSTYPE *ali_yyvs = ali_yyvsa;
-  YYSTYPE *ali_yyvsp;
+  register YYSTYPE *ali_yyvsp;
 
 
 
@@ -1042,14 +921,14 @@ ali_yyparse ()
 	   these so that the &'s don't force the real ones into
 	   memory.  */
 	YYSTYPE *ali_yyvs1 = ali_yyvs;
-	short int *ali_yyss1 = ali_yyss;
+	short *ali_yyss1 = ali_yyss;
 
 
 	/* Each stack pointer address is followed by the size of the
 	   data in use in that stack, in bytes.  This used to be a
 	   conditional around just the two extra args, but that might
 	   be undefined if ali_yyoverflow is a macro.  */
-	ali_yyoverflow (YY_("memory exhausted"),
+	ali_yyoverflow ("parser stack overflow",
 		    &ali_yyss1, ali_yysize * sizeof (*ali_yyssp),
 		    &ali_yyvs1, ali_yysize * sizeof (*ali_yyvsp),
 
@@ -1060,21 +939,21 @@ ali_yyparse ()
       }
 #else /* no ali_yyoverflow */
 # ifndef YYSTACK_RELOCATE
-      goto ali_yyexhaustedlab;
+      goto ali_yyoverflowlab;
 # else
       /* Extend the stack our own way.  */
       if (YYMAXDEPTH <= ali_yystacksize)
-	goto ali_yyexhaustedlab;
+	goto ali_yyoverflowlab;
       ali_yystacksize *= 2;
       if (YYMAXDEPTH < ali_yystacksize)
 	ali_yystacksize = YYMAXDEPTH;
 
       {
-	short int *ali_yyss1 = ali_yyss;
+	short *ali_yyss1 = ali_yyss;
 	union ali_yyalloc *ali_yyptr =
 	  (union ali_yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (ali_yystacksize));
 	if (! ali_yyptr)
-	  goto ali_yyexhaustedlab;
+	  goto ali_yyoverflowlab;
 	YYSTACK_RELOCATE (ali_yyss);
 	YYSTACK_RELOCATE (ali_yyvs);
 
@@ -1106,18 +985,18 @@ ali_yyparse ()
 ali_yybackup:
 
 /* Do appropriate processing given the current state.  */
-/* Read a look-ahead token if we need one and don't already have one.  */
+/* Read a lookahead token if we need one and don't already have one.  */
 /* ali_yyresume: */
 
-  /* First try to decide what to do without reference to look-ahead token.  */
+  /* First try to decide what to do without reference to lookahead token.  */
 
   ali_yyn = ali_yypact[ali_yystate];
   if (ali_yyn == YYPACT_NINF)
     goto ali_yydefault;
 
-  /* Not known => get a look-ahead token if don't already have one.  */
+  /* Not known => get a lookahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
   if (ali_yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1132,7 +1011,7 @@ ali_yybackup:
   else
     {
       ali_yytoken = YYTRANSLATE (ali_yychar);
-      YY_SYMBOL_PRINT ("Next token is", ali_yytoken, &ali_yylval, &ali_yylloc);
+      YYDSYMPRINTF ("Next token is", ali_yytoken, &ali_yylval, &ali_yylloc);
     }
 
   /* If the proper action on seeing token YYTOKEN is to reduce or to
@@ -1152,8 +1031,8 @@ ali_yybackup:
   if (ali_yyn == YYFINAL)
     YYACCEPT;
 
-  /* Shift the look-ahead token.  */
-  YY_SYMBOL_PRINT ("Shifting", ali_yytoken, &ali_yylval, &ali_yylloc);
+  /* Shift the lookahead token.  */
+  YYDPRINTF ((stderr, "Shifting token %s, ", ali_yytname[ali_yytoken]));
 
   /* Discard the token being shifted unless it is eof.  */
   if (ali_yychar != YYEOF)
@@ -1207,14 +1086,14 @@ ali_yyreduce:
     {
 		 if (!alias_list)
 		   alias_list = list_create_or_die ();
-		 mu_list_append (alias_list, (ali_yyvsp[0].alias));
+		 mu_list_append (alias_list, ali_yyvsp[0].alias);
 	       }
     break;
 
   case 8:
 #line 126 "mh_alias.y"
     {
-		 mu_list_append (alias_list, (ali_yyvsp[0].alias));
+		 mu_list_append (alias_list, ali_yyvsp[0].alias);
 	       }
     break;
 
@@ -1227,10 +1106,10 @@ ali_yyreduce:
 #line 136 "mh_alias.y"
     {
 		 ali_verbatim (0);
-		 (ali_yyval.alias) = xmalloc (sizeof (*(ali_yyval.alias)));
-		 (ali_yyval.alias)->name = (ali_yyvsp[-3].string);
-		 (ali_yyval.alias)->rcpt_list = (ali_yyvsp[0].list);
-		 (ali_yyval.alias)->inclusive = 0;
+		 ali_yyval.alias = xmalloc (sizeof (*ali_yyval.alias));
+		 ali_yyval.alias->name = ali_yyvsp[-3].string;
+		 ali_yyval.alias->rcpt_list = ali_yyvsp[0].list;
+		 ali_yyval.alias->inclusive = 0;
 	       }
     break;
 
@@ -1243,81 +1122,80 @@ ali_yyreduce:
 #line 144 "mh_alias.y"
     {
 		 ali_verbatim (0);
-		 (ali_yyval.alias) = xmalloc (sizeof (*(ali_yyval.alias)));
-		 (ali_yyval.alias)->name = (ali_yyvsp[-3].string);
-		 (ali_yyval.alias)->rcpt_list = (ali_yyvsp[0].list);
-		 (ali_yyval.alias)->inclusive = 1;
+		 ali_yyval.alias = xmalloc (sizeof (*ali_yyval.alias));
+		 ali_yyval.alias->name = ali_yyvsp[-3].string;
+		 ali_yyval.alias->rcpt_list = ali_yyvsp[0].list;
+		 ali_yyval.alias->inclusive = 1;
 	       }
     break;
 
   case 16:
 #line 155 "mh_alias.y"
     {
-		 (ali_yyval.list) = unix_group_to_list ((ali_yyvsp[0].string));
-		 free ((ali_yyvsp[0].string));
+		 ali_yyval.list = unix_group_to_list (ali_yyvsp[0].string);
+		 free (ali_yyvsp[0].string);
 	       }
     break;
 
   case 17:
 #line 160 "mh_alias.y"
     {
-		 (ali_yyval.list) = unix_gid_to_list ((ali_yyvsp[0].string));
-		 free ((ali_yyvsp[0].string));
+		 ali_yyval.list = unix_gid_to_list (ali_yyvsp[0].string);
+		 free (ali_yyvsp[0].string);
 	       }
     break;
 
   case 18:
 #line 165 "mh_alias.y"
     {
-		 (ali_yyval.list) = unix_passwd_to_list ();
+		 ali_yyval.list = unix_passwd_to_list ();
 	       }
     break;
 
   case 19:
 #line 171 "mh_alias.y"
     {
-		 (ali_yyval.list) = list_create_or_die ();
-		 mu_list_append ((ali_yyval.list), (ali_yyvsp[0].string));
+		 ali_yyval.list = list_create_or_die ();
+		 mu_list_append (ali_yyval.list, ali_yyvsp[0].string);
 	       }
     break;
 
   case 20:
 #line 176 "mh_alias.y"
     {
-		 mu_list_append ((ali_yyvsp[-2].list), (ali_yyvsp[0].string));
-		 (ali_yyval.list) = (ali_yyvsp[-2].list);
+		 mu_list_append (ali_yyvsp[-2].list, ali_yyvsp[0].string);
+		 ali_yyval.list = ali_yyvsp[-2].list;
 	       }
     break;
 
   case 21:
 #line 183 "mh_alias.y"
     {
-		 (ali_yyval.string) = ali_list_to_string (&(ali_yyvsp[0].list));
+		 ali_yyval.string = ali_list_to_string (&ali_yyvsp[0].list);
 	       }
     break;
 
   case 22:
 #line 189 "mh_alias.y"
     {
-		 mu_list_create(&(ali_yyval.list));
-		 mu_list_append((ali_yyval.list), (ali_yyvsp[0].string));
+		 mu_list_create(&ali_yyval.list);
+		 mu_list_append(ali_yyval.list, ali_yyvsp[0].string);
 	       }
     break;
 
   case 23:
 #line 194 "mh_alias.y"
     {
-		 mu_list_append((ali_yyvsp[-1].list), (ali_yyvsp[0].string));
-		 (ali_yyval.list) = (ali_yyvsp[-1].list);
+		 mu_list_append(ali_yyvsp[-1].list, ali_yyvsp[0].string);
+		 ali_yyval.list = ali_yyvsp[-1].list;
 	       }
     break;
 
 
-      default: break;
     }
 
-/* Line 1126 of yacc.c.  */
-#line 1321 "mh_alias_gram.c"
+/* Line 991 of yacc.c.  */
+#line 1198 "mh_alias_gram.c"
 
   ali_yyvsp -= ali_yylen;
   ali_yyssp -= ali_yylen;
@@ -1356,153 +1234,103 @@ ali_yyerrlab:
 
       if (YYPACT_NINF < ali_yyn && ali_yyn < YYLAST)
 	{
+	  YYSIZE_T ali_yysize = 0;
 	  int ali_yytype = YYTRANSLATE (ali_yychar);
-	  YYSIZE_T ali_yysize0 = ali_yytnamerr (0, ali_yytname[ali_yytype]);
-	  YYSIZE_T ali_yysize = ali_yysize0;
-	  YYSIZE_T ali_yysize1;
-	  int ali_yysize_overflow = 0;
-	  char *ali_yymsg = 0;
-#	  define YYERROR_VERBOSE_ARGS_MAXIMUM 5
-	  char const *ali_yyarg[YYERROR_VERBOSE_ARGS_MAXIMUM];
-	  int ali_yyx;
-
-#if 0
-	  /* This is so xgettext sees the translatable formats that are
-	     constructed on the fly.  */
-	  YY_("syntax error, unexpected %s");
-	  YY_("syntax error, unexpected %s, expecting %s");
-	  YY_("syntax error, unexpected %s, expecting %s or %s");
-	  YY_("syntax error, unexpected %s, expecting %s or %s or %s");
-	  YY_("syntax error, unexpected %s, expecting %s or %s or %s or %s");
-#endif
-	  char *ali_yyfmt;
-	  char const *ali_yyf;
-	  static char const ali_yyunexpected[] = "syntax error, unexpected %s";
-	  static char const ali_yyexpecting[] = ", expecting %s";
-	  static char const ali_yyor[] = " or %s";
-	  char ali_yyformat[sizeof ali_yyunexpected
-			+ sizeof ali_yyexpecting - 1
-			+ ((YYERROR_VERBOSE_ARGS_MAXIMUM - 2)
-			   * (sizeof ali_yyor - 1))];
-	  char const *ali_yyprefix = ali_yyexpecting;
+	  char *ali_yymsg;
+	  int ali_yyx, ali_yycount;
 
+	  ali_yycount = 0;
 	  /* Start YYX at -YYN if negative to avoid negative indexes in
 	     YYCHECK.  */
-	  int ali_yyxbegin = ali_yyn < 0 ? -ali_yyn : 0;
-
-	  /* Stay within bounds of both ali_yycheck and ali_yytname.  */
-	  int ali_yychecklim = YYLAST - ali_yyn;
-	  int ali_yyxend = ali_yychecklim < YYNTOKENS ? ali_yychecklim : YYNTOKENS;
-	  int ali_yycount = 1;
-
-	  ali_yyarg[0] = ali_yytname[ali_yytype];
-	  ali_yyfmt = ali_yystpcpy (ali_yyformat, ali_yyunexpected);
-
-	  for (ali_yyx = ali_yyxbegin; ali_yyx < ali_yyxend; ++ali_yyx)
+	  for (ali_yyx = ali_yyn < 0 ? -ali_yyn : 0;
+	       ali_yyx < (int) (sizeof (ali_yytname) / sizeof (char *)); ali_yyx++)
 	    if (ali_yycheck[ali_yyx + ali_yyn] == ali_yyx && ali_yyx != YYTERROR)
-	      {
-		if (ali_yycount == YYERROR_VERBOSE_ARGS_MAXIMUM)
-		  {
-		    ali_yycount = 1;
-		    ali_yysize = ali_yysize0;
-		    ali_yyformat[sizeof ali_yyunexpected - 1] = '\0';
-		    break;
-		  }
-		ali_yyarg[ali_yycount++] = ali_yytname[ali_yyx];
-		ali_yysize1 = ali_yysize + ali_yytnamerr (0, ali_yytname[ali_yyx]);
-		ali_yysize_overflow |= ali_yysize1 < ali_yysize;
-		ali_yysize = ali_yysize1;
-		ali_yyfmt = ali_yystpcpy (ali_yyfmt, ali_yyprefix);
-		ali_yyprefix = ali_yyor;
-	      }
-
-	  ali_yyf = YY_(ali_yyformat);
-	  ali_yysize1 = ali_yysize + ali_yystrlen (ali_yyf);
-	  ali_yysize_overflow |= ali_yysize1 < ali_yysize;
-	  ali_yysize = ali_yysize1;
-
-	  if (!ali_yysize_overflow && ali_yysize <= YYSTACK_ALLOC_MAXIMUM)
-	    ali_yymsg = (char *) YYSTACK_ALLOC (ali_yysize);
-	  if (ali_yymsg)
+	      ali_yysize += ali_yystrlen (ali_yytname[ali_yyx]) + 15, ali_yycount++;
+	  ali_yysize += ali_yystrlen ("syntax error, unexpected ") + 1;
+	  ali_yysize += ali_yystrlen (ali_yytname[ali_yytype]);
+	  ali_yymsg = (char *) YYSTACK_ALLOC (ali_yysize);
+	  if (ali_yymsg != 0)
 	    {
-	      /* Avoid sprintf, as that infringes on the user's name space.
-		 Don't have undefined behavior even if the translation
-		 produced a string with the wrong number of "%s"s.  */
-	      char *ali_yyp = ali_yymsg;
-	      int ali_yyi = 0;
-	      while ((*ali_yyp = *ali_yyf))
+	      char *ali_yyp = ali_yystpcpy (ali_yymsg, "syntax error, unexpected ");
+	      ali_yyp = ali_yystpcpy (ali_yyp, ali_yytname[ali_yytype]);
+
+	      if (ali_yycount < 5)
 		{
-		  if (*ali_yyp == '%' && ali_yyf[1] == 's' && ali_yyi < ali_yycount)
-		    {
-		      ali_yyp += ali_yytnamerr (ali_yyp, ali_yyarg[ali_yyi++]);
-		      ali_yyf += 2;
-		    }
-		  else
-		    {
-		      ali_yyp++;
-		      ali_yyf++;
-		    }
+		  ali_yycount = 0;
+		  for (ali_yyx = ali_yyn < 0 ? -ali_yyn : 0;
+		       ali_yyx < (int) (sizeof (ali_yytname) / sizeof (char *));
+		       ali_yyx++)
+		    if (ali_yycheck[ali_yyx + ali_yyn] == ali_yyx && ali_yyx != YYTERROR)
+		      {
+			const char *ali_yyq = ! ali_yycount ? ", expecting " : " or ";
+			ali_yyp = ali_yystpcpy (ali_yyp, ali_yyq);
+			ali_yyp = ali_yystpcpy (ali_yyp, ali_yytname[ali_yyx]);
+			ali_yycount++;
+		      }
 		}
 	      ali_yyerror (ali_yymsg);
 	      YYSTACK_FREE (ali_yymsg);
 	    }
 	  else
-	    {
-	      ali_yyerror (YY_("syntax error"));
-	      goto ali_yyexhaustedlab;
-	    }
+	    ali_yyerror ("syntax error; also virtual memory exhausted");
 	}
       else
 #endif /* YYERROR_VERBOSE */
-	ali_yyerror (YY_("syntax error"));
+	ali_yyerror ("syntax error");
     }
 
 
 
   if (ali_yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse look-ahead token after an
+      /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
-      if (ali_yychar <= YYEOF)
+      /* Return failure if at end of input.  */
+      if (ali_yychar == YYEOF)
         {
-	  /* Return failure if at end of input.  */
-	  if (ali_yychar == YYEOF)
-	    YYABORT;
+	  /* Pop the error token.  */
+          YYPOPSTACK;
+	  /* Pop the rest of the stack.  */
+	  while (ali_yyss < ali_yyssp)
+	    {
+	      YYDSYMPRINTF ("Error: popping", ali_yystos[*ali_yyssp], ali_yyvsp, ali_yylsp);
+	      ali_yydestruct (ali_yystos[*ali_yyssp], ali_yyvsp);
+	      YYPOPSTACK;
+	    }
+	  YYABORT;
         }
-      else
-	{
-	  ali_yydestruct ("Error: discarding", ali_yytoken, &ali_yylval);
-	  ali_yychar = YYEMPTY;
-	}
+
+      YYDSYMPRINTF ("Error: discarding", ali_yytoken, &ali_yylval, &ali_yylloc);
+      ali_yydestruct (ali_yytoken, &ali_yylval);
+      ali_yychar = YYEMPTY;
+
     }
 
-  /* Else will try to reuse look-ahead token after shifting the error
+  /* Else will try to reuse lookahead token after shifting the error
      token.  */
-  goto ali_yyerrlab1;
+  goto ali_yyerrlab2;
 
 
-/*---------------------------------------------------.
-| ali_yyerrorlab -- error raised explicitly by YYERROR.  |
-`---------------------------------------------------*/
-ali_yyerrorlab:
-
-  /* Pacify compilers like GCC when the user code never invokes
-     YYERROR and the label ali_yyerrorlab therefore never appears in user
-     code.  */
-  if (0)
-     goto ali_yyerrorlab;
-
-ali_yyvsp -= ali_yylen;
-  ali_yyssp -= ali_yylen;
-  ali_yystate = *ali_yyssp;
-  goto ali_yyerrlab1;
-
-
-/*-------------------------------------------------------------.
-| ali_yyerrlab1 -- common code for both syntax error and YYERROR.  |
-`-------------------------------------------------------------*/
+/*----------------------------------------------------.
+| ali_yyerrlab1 -- error raised explicitly by an action.  |
+`----------------------------------------------------*/
 ali_yyerrlab1:
+
+  /* Suppress GCC warning that ali_yyerrlab1 is unused when no action
+     invokes YYERROR.  */
+#if defined (__GNUC_MINOR__) && 2093 <= (__GNUC__ * 1000 + __GNUC_MINOR__)
+  __attribute__ ((__unused__))
+#endif
+
+
+  goto ali_yyerrlab2;
+
+
+/*---------------------------------------------------------------.
+| ali_yyerrlab2 -- pop states until the error token can be shifted.  |
+`---------------------------------------------------------------*/
+ali_yyerrlab2:
   ali_yyerrstatus = 3;	/* Each real token shifted decrements this.  */
 
   for (;;)
@@ -1523,22 +1351,22 @@ ali_yyerrlab1:
       if (ali_yyssp == ali_yyss)
 	YYABORT;
 
+      YYDSYMPRINTF ("Error: popping", ali_yystos[*ali_yyssp], ali_yyvsp, ali_yylsp);
+      ali_yydestruct (ali_yystos[ali_yystate], ali_yyvsp);
+      ali_yyvsp--;
+      ali_yystate = *--ali_yyssp;
 
-      ali_yydestruct ("Error: popping", ali_yystos[ali_yystate], ali_yyvsp);
-      YYPOPSTACK;
-      ali_yystate = *ali_yyssp;
       YY_STACK_PRINT (ali_yyss, ali_yyssp);
     }
 
   if (ali_yyn == YYFINAL)
     YYACCEPT;
 
+  YYDPRINTF ((stderr, "Shifting error token, "));
+
   *++ali_yyvsp = ali_yylval;
 
 
-  /* Shift the error token. */
-  YY_SYMBOL_PRINT ("Shifting", ali_yystos[ali_yyn], ali_yyvsp, ali_yylsp);
-
   ali_yystate = ali_yyn;
   goto ali_yynewstate;
 
@@ -1558,25 +1386,16 @@ ali_yyabortlab:
   goto ali_yyreturn;
 
 #ifndef ali_yyoverflow
-/*-------------------------------------------------.
-| ali_yyexhaustedlab -- memory exhaustion comes here.  |
-`-------------------------------------------------*/
-ali_yyexhaustedlab:
-  ali_yyerror (YY_("memory exhausted"));
+/*----------------------------------------------.
+| ali_yyoverflowlab -- parser overflow comes here.  |
+`----------------------------------------------*/
+ali_yyoverflowlab:
+  ali_yyerror ("parser stack overflow");
   ali_yyresult = 2;
   /* Fall through.  */
 #endif
 
 ali_yyreturn:
-  if (ali_yychar != YYEOF && ali_yychar != YYEMPTY)
-     ali_yydestruct ("Cleanup: discarding lookahead",
-		 ali_yytoken, &ali_yylval);
-  while (ali_yyssp != ali_yyss)
-    {
-      ali_yydestruct ("Cleanup: popping",
-		  ali_yystos[*ali_yyssp], ali_yyvsp);
-      YYPOPSTACK;
-    }
 #ifndef ali_yyoverflow
   if (ali_yyss != ali_yyssa)
     YYSTACK_FREE (ali_yyss);
@@ -1722,10 +1541,10 @@ mh_alias_get_internal (char *name, mu_iterator_t start, mu_list_t *return_list,
     {
       struct mh_alias *alias;
       mu_iterator_current (itr, (void **)&alias);
-      if (inclusive)
-	*inclusive |= alias->inclusive;
       if (aliascmp (alias->name, name) == 0)
 	{
+	  if (inclusive)
+	    *inclusive |= alias->inclusive;
 	  *return_list = ali_list_dup (alias->rcpt_list);
 	  alias_expand_list (*return_list, itr, inclusive);
 	  rc = 0;
@@ -1748,8 +1567,9 @@ mh_alias_get_address (char *name, mu_address_t *paddr, int *incl)
 {
   mu_iterator_t itr;
   mu_list_t list;
-  const char *domain = NULL;
-  
+
+  if (incl)
+    *incl = 0;
   if (mh_alias_get_internal (name, NULL, &list, incl))
     return 1;
   if (mu_list_is_empty (list))
@@ -1767,25 +1587,15 @@ mh_alias_get_address (char *name, mu_address_t *paddr, int *incl)
 	  char *ptr = NULL; 
 
 	  mu_iterator_current (itr, (void **)&item);
-	  if (incl && *incl)
-	    {
-	      if (strchr (item, '@') == 0)
-		{
-		  if (!domain)
-		    mu_get_user_email_domain (&domain);
-		  asprintf (&ptr, "\"%s\" <%s@%s>", name, item, domain);
-		}
-	      else
-		asprintf (&ptr, "\"%s\" <%s>", name, item);
-	      item = ptr;
-	    }
 	  if (mu_address_create (&a, item))
 	    {
-	      mh_error (_("Error expanding aliases -- invalid address `%s'"),
+	      mu_error (_("Error expanding aliases -- invalid address `%s'"),
 			item);
 	    }
 	  else
 	    {
+	      if (incl && *incl)
+		mu_address_set_personal (a, 1, name);
 	      mu_address_union (paddr, a);
 	      mu_address_destroy (&a);
 	    }
