@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 2003 Free Software Foundation, Inc.
+   Copyright (C) 2003, 2005, 2006 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -71,7 +71,7 @@ struct mhl_stmt_variable
 struct mhl_stmt_component
 {
   char *name;
-  list_t format;
+  mu_list_t format;
 };
 
 struct mhl_stmt
@@ -85,7 +85,7 @@ struct mhl_stmt
   } v;
 };
 
-static mhl_variable_t *variable_lookup __P((char *name));
+static mhl_variable_t *variable_lookup (char *name);
 
 static mhl_stmt_t *
 stmt_alloc (enum mhl_type type)
@@ -115,10 +115,10 @@ compdecl (char **str, char **compname)
   return 1;
 }
 
-static void parse_variable (locus_t *loc, list_t formlist, char *str);
+static void parse_variable (locus_t *loc, mu_list_t formlist, char *str);
 
 static void
-parse_cleartext (locus_t *loc, list_t formlist, char *str)
+parse_cleartext (locus_t *loc, mu_list_t formlist, char *str)
 {
   int len;
   mhl_stmt_t *stmt = stmt_alloc (stmt_cleartext);
@@ -126,36 +126,36 @@ parse_cleartext (locus_t *loc, list_t formlist, char *str)
   len = strlen (stmt->v.cleartext);
   if (len > 0 && stmt->v.cleartext[len-1] == '\n')
     stmt->v.cleartext[len-1] = 0;
-  list_append (formlist, stmt);
+  mu_list_append (formlist, stmt);
 }
 
 static void
-parse_component (locus_t *loc, list_t formlist, char *compname, char *str)
+parse_component (locus_t *loc, mu_list_t formlist, char *compname, char *str)
 {
   mhl_stmt_t *stmt = stmt_alloc (stmt_component);
   stmt->v.component.name = compname;
-  if (list_create (&stmt->v.component.format))
+  if (mu_list_create (&stmt->v.component.format))
     {
-      mh_error (_("%s:%d: cannot create list"),
+      mu_error (_("%s:%d: cannot create list"),
 		loc->filename,
 		loc->line);
       exit (1); /* FIXME */
     }
   parse_variable (loc, stmt->v.component.format, str);
-  list_append (formlist, stmt);
+  mu_list_append (formlist, stmt);
 }
 
 static void
-parse_variable (locus_t *loc, list_t formlist, char *str)
+parse_variable (locus_t *loc, mu_list_t formlist, char *str)
 {
   int i;
   int argc;
   char **argv;
   mh_format_t fmt;
   
-  if (argcv_get (str, ",=", NULL, &argc, &argv))
+  if (mu_argcv_get (str, ",=", NULL, &argc, &argv))
     {
-      mh_error (_("%s:%d: cannot split string %s"),
+      mu_error (_("%s:%d: cannot split string %s"),
 		loc->filename,
 		loc->line,
 		str);
@@ -172,7 +172,7 @@ parse_variable (locus_t *loc, list_t formlist, char *str)
       var = variable_lookup (name);
       if (!var)
 	{
-	  mh_error (_("%s:%d: unknown variable: %s"),
+	  mu_error (_("%s:%d: unknown variable: %s"),
 		    loc->filename,
 		    loc->line,
 		    argv[i]);
@@ -188,7 +188,7 @@ parse_variable (locus_t *loc, list_t formlist, char *str)
       if ((var->type == dt_flag && value)
 	  || (var->type != dt_flag && !value))
 	{
-	  mh_error (_("%s:%d: wrong datatype for %s"),
+	  mu_error (_("%s:%d: wrong datatype for %s"),
 		    loc->filename,
 		    loc->line,
 		    var->name);
@@ -208,7 +208,7 @@ parse_variable (locus_t *loc, list_t formlist, char *str)
 	case dt_format:
 	  if (mh_format_parse (value, &fmt))
 	    {
-	      mh_error (_("%s:%d: bad format string"),
+	      mu_error (_("%s:%d: bad format string"),
 			loc->filename,
 			loc->line);
 	      exit (1);
@@ -222,21 +222,21 @@ parse_variable (locus_t *loc, list_t formlist, char *str)
 	  break;
 	}
       stmt->v.variable.id = var;
-      list_append (formlist, stmt);
+      mu_list_append (formlist, stmt);
 
       i++;
       if (i < argc && argv[i][0] != ',')
 	{
-	  mh_error (_("%s:%d: syntax error"), loc->filename, loc->line);
+	  mu_error (_("%s:%d: syntax error"), loc->filename, loc->line);
 	  exit (1);
 	}
     }
 
-  argcv_free (argc, argv);
+  mu_argcv_free (argc, argv);
 }
 
 static int
-parse_line (locus_t *loc, list_t formlist, char *str)
+parse_line (locus_t *loc, mu_list_t formlist, char *str)
 {
   char *compname;
   
@@ -249,11 +249,11 @@ parse_line (locus_t *loc, list_t formlist, char *str)
   return 0;
 }
 
-list_t 
+mu_list_t 
 mhl_format_compile (char *name)
 {
   FILE *fp;
-  list_t formlist;
+  mu_list_t formlist;
   char *buf = NULL;
   size_t n = 0;
   locus_t loc;
@@ -261,14 +261,14 @@ mhl_format_compile (char *name)
   fp = fopen (name, "r");
   if (!fp)
     {
-      mh_error (_("Cannot open file %s: %s"), name, mu_strerror (errno));
+      mu_error (_("Cannot open file %s: %s"), name, mu_strerror (errno));
       return NULL;
     }
 
-  if (list_create (&formlist))
+  if (mu_list_create (&formlist))
     {
       fclose (fp);
-      mh_error (_("Cannot create list"));
+      mu_error (_("Cannot create list"));
       return NULL;
     }
 
@@ -347,10 +347,10 @@ _destroy_stmt (void *item, void *data)
 }
 
 void
-mhl_format_destroy (list_t *fmt)
+mhl_format_destroy (mu_list_t *fmt)
 {
-  list_do (*fmt, _destroy_stmt, NULL);
-  list_destroy (fmt);
+  mu_list_do (*fmt, _destroy_stmt, NULL);
+  mu_list_destroy (fmt);
 }
 
 
@@ -441,9 +441,9 @@ variable_lookup (char *name)
 
 struct eval_env
 {
-  message_t msg;
-  stream_t output;
-  list_t printed_fields;  /* A list of printed header names */
+  mu_message_t msg;
+  mu_stream_t output;
+  mu_list_t printed_fields;  /* A list of printed header names */
   int pos;
   int nlines;
   int ivar[I_MAX];
@@ -467,7 +467,7 @@ _comp_name (void *item, void *date)
 int
 header_is_printed (struct eval_env *env, char *name)
 {
-  return list_do (env->printed_fields, _comp_name, name) == 1;
+  return mu_list_do (env->printed_fields, _comp_name, name) == 1;
 }
 
 int
@@ -527,7 +527,7 @@ ovf_print (struct eval_env *env, char *str, int size, int nloff)
 	  if (env->svar[S_OVERFLOWTEXT])
 	    {
 	      int l = strlen (env->svar[S_OVERFLOWTEXT]);
-	      stream_sequential_write (env->output,
+	      mu_stream_sequential_write (env->output,
 				       env->svar[S_OVERFLOWTEXT], l);
 	      env->pos += l;
 	    }
@@ -538,7 +538,7 @@ ovf_print (struct eval_env *env, char *str, int size, int nloff)
 	    {
 	      goto_offset (env, env->ivar[I_OFFSET]);
 	      
-	      stream_sequential_write (env->output, env->prefix,
+	      mu_stream_sequential_write (env->output, env->prefix,
 				       strlen (env->prefix));
 	      env->pos += strlen (env->prefix);
 	      
@@ -552,7 +552,7 @@ ovf_print (struct eval_env *env, char *str, int size, int nloff)
 	  len = env->ivar[I_WIDTH] - env->pos;
 	}
       
-      stream_sequential_write (env->output, str, len);
+      mu_stream_sequential_write (env->output, str, len);
       env->pos += len;
       if (env->pos >= env->ivar[I_WIDTH])
 	newline (env);
@@ -590,15 +590,15 @@ print (struct eval_env *env, char *str, int nloff)
 static void
 newline (struct eval_env *env)
 {
-  stream_sequential_write (env->output, "\n", 1);
+  mu_stream_sequential_write (env->output, "\n", 1);
   env->pos = 0;
   if (env->ivar[I_LENGTH] && ++env->nlines >= env->ivar[I_LENGTH])
     {
       /* FIXME: Better to write it directly on the terminal */
       if (env->bvar[B_BELL])
-	stream_sequential_write (env->output, "\a", 1);
+	mu_stream_sequential_write (env->output, "\a", 1);
       if (env->bvar[B_CLEARSCREEN])
-	stream_sequential_write (env->output, "\f", 1);
+	mu_stream_sequential_write (env->output, "\f", 1);
       env->nlines = 0;
     }
 }
@@ -607,7 +607,7 @@ static void
 goto_offset (struct eval_env *env, int count)
 {
   for (; env->pos < count; env->pos++)
-    stream_sequential_write (env->output, " ", 1);
+    mu_stream_sequential_write (env->output, " ", 1);
 }
 
 int
@@ -654,14 +654,14 @@ print_header_value (struct eval_env *env, char *val)
 int
 eval_component (struct eval_env *env, char *name)
 {
-  header_t hdr;
+  mu_header_t hdr;
   char *val;
   
-  message_get_header (env->msg, &hdr);
-  if (header_aget_value (hdr, name, &val))
+  mu_message_get_header (env->msg, &hdr);
+  if (mu_header_aget_value (hdr, name, &val))
     return 0;
 
-  list_append (env->printed_fields, name);
+  mu_list_append (env->printed_fields, name);
   print_header_value (env, val);
   free (val);
   return 0;
@@ -670,30 +670,30 @@ eval_component (struct eval_env *env, char *name)
 int
 eval_body (struct eval_env *env)
 {
-  stream_t input = NULL;
-  stream_t dstr = NULL;
+  mu_stream_t input = NULL;
+  mu_stream_t dstr = NULL;
   char buf[128]; /* FIXME: Fixed size. Bad */
   size_t n;
-  body_t body = NULL;
+  mu_body_t body = NULL;
 
   if (env->bvar[B_DISABLE_BODY])
     return 0;
   
   env->prefix = env->svar[S_COMPONENT];
 
-  message_get_body (env->msg, &body);
-  body_get_stream (body, &input);
+  mu_message_get_body (env->msg, &body);
+  mu_body_get_stream (body, &input);
 
   if (env->bvar[B_DECODE])
     {
-      header_t hdr;
+      mu_header_t hdr;
       char *encoding = NULL;
 
-      message_get_header (env->msg, &hdr);
-      header_aget_value (hdr, MU_HEADER_CONTENT_TRANSFER_ENCODING, &encoding);
+      mu_message_get_header (env->msg, &hdr);
+      mu_header_aget_value (hdr, MU_HEADER_CONTENT_TRANSFER_ENCODING, &encoding);
       if (encoding)
 	{
-	  int rc = filter_create(&dstr, input, encoding,
+	  int rc = mu_filter_create(&dstr, input, encoding,
 				 MU_FILTER_DECODE, MU_STREAM_READ);
 	  if (rc == 0)
 	    input = dstr;
@@ -701,37 +701,37 @@ eval_body (struct eval_env *env)
 	}
     }
   
-  stream_seek (input, 0, SEEK_SET);
-  while (stream_sequential_readline (input, buf, sizeof buf, &n) == 0
+  mu_stream_seek (input, 0, SEEK_SET);
+  while (mu_stream_sequential_readline (input, buf, sizeof buf, &n) == 0
 	 && n > 0)
     {
       buf[n] = 0;
       print (env, buf, 0);
     }
   if (dstr)
-    stream_destroy (&dstr, stream_get_owner (dstr));
+    mu_stream_destroy (&dstr, mu_stream_get_owner (dstr));
   return 0;
 }
 
 int
 eval_extras (struct eval_env *env)
 {
-  header_t hdr;
+  mu_header_t hdr;
   size_t i, num;
   char buf[512];
 
-  message_get_header (env->msg, &hdr);
-  header_get_field_count (hdr, &num);
+  mu_message_get_header (env->msg, &hdr);
+  mu_header_get_field_count (hdr, &num);
   for (i = 1; i <= num; i++)
     {
-      header_get_field_name (hdr, i, buf, sizeof buf, NULL);
+      mu_header_get_field_name (hdr, i, buf, sizeof buf, NULL);
       if (want_header (env, buf)
 	  && !header_is_printed (env, buf))
 	{
 	  goto_offset (env, env->ivar[I_OFFSET]);
 	  print (env, buf, 0);
 	  print (env, ":", 0);
-	  header_get_field_value (hdr, i, buf, sizeof buf, NULL);
+	  mu_header_get_field_value (hdr, i, buf, sizeof buf, NULL);
 	  print_header_value (env, buf);
 	  if (env->bvar[B_NEWLINE])
 	    newline (env);
@@ -741,11 +741,11 @@ eval_extras (struct eval_env *env)
 }
 
 int
-eval_comp (struct eval_env *env, char *compname, list_t format)
+eval_comp (struct eval_env *env, char *compname, mu_list_t format)
 {
   struct eval_env lenv = *env;
   
-  list_do (format, eval_stmt, &lenv);
+  mu_list_do (format, eval_stmt, &lenv);
 
   goto_offset (&lenv, lenv.ivar[I_OFFSET]);
 
@@ -804,9 +804,9 @@ eval_stmt (void *item, void *data)
 }
 
 int
-mhl_format_run (list_t fmt,
+mhl_format_run (mu_list_t fmt,
 		int width, int length, int flags,
-		message_t msg, stream_t output)
+		mu_message_t msg, mu_stream_t output)
 {
   int rc;
   struct eval_env env;
@@ -815,7 +815,7 @@ mhl_format_run (list_t fmt,
   memset (&env, 0, sizeof (env));
 
   env.bvar[B_NEWLINE] = 1;
-  list_create (&env.printed_fields);
+  mu_list_create (&env.printed_fields);
   env.ivar[I_WIDTH] = width;
   env.ivar[I_LENGTH] = length;
   env.bvar[B_CLEARSCREEN] = flags & MHL_CLEARSCREEN;
@@ -826,7 +826,7 @@ mhl_format_run (list_t fmt,
   env.nlines = 0;
   env.msg = msg;
   env.output = output;
-  rc = list_do (fmt, eval_stmt, &env);
-  list_destroy (&env.printed_fields);
+  rc = mu_list_do (fmt, eval_stmt, &env);
+  mu_list_destroy (&env.printed_fields);
   return rc;
 }
