@@ -1,5 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999, 2000, 2001 Free Software Foundation, Inc.
+   Copyright (C) 1999, 2000, 2001, 2005 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -29,8 +29,8 @@ pop3d_stat (const char *arg)
   size_t total = 0;
   size_t num = 0;
   size_t tsize = 0;
-  message_t msg = NULL;
-  attribute_t attr = NULL;
+  mu_message_t msg = NULL;
+  mu_attribute_t attr = NULL;
 
   if (strlen (arg) != 0)
     return ERR_BAD_ARGS;
@@ -41,22 +41,22 @@ pop3d_stat (const char *arg)
   /* rfc1939: if the POP3 server host internally represents end-of-line as a
      single character, then the POP3 server simply counts each occurrence of
      this character in a message as two octets. */
-  mailbox_messages_count (mbox, &total);
+  mu_mailbox_messages_count (mbox, &total);
   for (mesgno = 1; mesgno <= total; mesgno++)
     {
-      mailbox_get_message (mbox, mesgno, &msg);
-      message_get_attribute (msg, &attr);
+      mu_mailbox_get_message (mbox, mesgno, &msg);
+      mu_message_get_attribute (msg, &attr);
       /* rfc1939: Note that messages marked as deleted are not counted in
 	 either total.  */
       if (!pop3d_is_deleted (attr))
 	{
-	  message_size (msg, &size);
-	  message_lines (msg, &lines);
+	  mu_message_size (msg, &size);
+	  mu_message_lines (msg, &lines);
 	  tsize += size + lines;
 	  num++;
 	}
     }
-  pop3d_outf ("+OK %d %d\r\n", num, tsize);
+  pop3d_outf ("+OK %s %s\r\n", mu_umaxtostr (0, num), mu_umaxtostr (1, tsize));
 
   return OK;
 }
