@@ -11,9 +11,10 @@
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.
 
-   You should have received a copy of the GNU Lesser General Public
-   License along with this library; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA  */
+   You should have received a copy of the GNU Lesser General
+   Public License along with this library; if not, write to the
+   Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301 USA */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
@@ -32,7 +33,7 @@ struct mu_odbc_data
   SQLHDBC dbc;        /* DBC */
                       /* Result data: */ 
   SQLHSTMT stmt;      /* Statement being executed */
-  list_t result;      /* List of returned field values */
+  mu_list_t result;      /* List of returned field values */
                       /* Error reporting: */
   struct odbc_err_buffer
   {
@@ -171,7 +172,7 @@ static int
 store_result (mu_sql_connection_t conn)
 {
   struct mu_odbc_data *dp = conn->data;
-  list_create (&dp->result);
+  mu_list_create (&dp->result);
   return 0;
 }
 
@@ -186,8 +187,8 @@ static int
 release_result (mu_sql_connection_t conn)
 {
   struct mu_odbc_data *dp = conn->data;
-  list_do (dp->result, free_char_data, NULL);
-  list_destroy (&dp->result);
+  mu_list_do (dp->result, free_char_data, NULL);
+  mu_list_destroy (&dp->result);
   return 0;
 }
 
@@ -242,7 +243,7 @@ get_column (mu_sql_connection_t conn, size_t nrow, size_t ncol, char **pdata)
     }
   
   *pdata = strdup (buffer);
-  list_append (dp->result, *pdata);
+  mu_list_append (dp->result, *pdata);
   return 0;
 }
 
